# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sequence_and_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import authentication_pb2 as authentication__pb2
from . import groups_pb2 as groups__pb2
from . import stickers_pb2 as stickers__pb2
from . import presence_pb2 as presence__pb2
from . import event_bus_pb2 as event__bus__pb2
from . import web_rtc_pb2 as web__rtc__pb2
from . import config_sync_pb2 as config__sync__pb2
from . import counters_pb2 as counters__pb2
from . import contacts_pb2 as contacts__pb2
from . import privacy_pb2 as privacy__pb2
from . import peers_pb2 as peers__pb2
from . import messaging_pb2 as messaging__pb2
from . import users_pb2 as users__pb2
from . import spaces_pb2 as spaces__pb2
from . import reactions_pb2 as reactions__pb2
from . import permissions_pb2 as permissions__pb2
from . import events_pb2 as events__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from . import miniappsregistry_pb2 as miniappsregistry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sequence_and_updates.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1asequence_and_updates.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x14\x61uthentication.proto\x1a\x0cgroups.proto\x1a\x0estickers.proto\x1a\x0epresence.proto\x1a\x0f\x65vent_bus.proto\x1a\rweb_rtc.proto\x1a\x11\x63onfig_sync.proto\x1a\x0e\x63ounters.proto\x1a\x0e\x63ontacts.proto\x1a\rprivacy.proto\x1a\x0bpeers.proto\x1a\x0fmessaging.proto\x1a\x0busers.proto\x1a\x0cspaces.proto\x1a\x0freactions.proto\x1a\x11permissions.proto\x1a\x0c\x65vents.proto\x1a\x15scalapb/scalapb.proto\x1a\x16miniappsregistry.proto\"\xa7\x30\n\x0fUpdateSeqUpdate\x12\x1a\n\x03seq\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\x12$\n\rupdate_header\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\x16updateForceReloadState\x18\x04 \x01(\x0b\x32\x1e.dialog.UpdateForceReloadStateH\x00\x12\x42\n\x17updateUserAvatarChanged\x18\x05 \x01(\x0b\x32\x1f.dialog.UpdateUserAvatarChangedH\x00\x12>\n\x15updateUserNameChanged\x18\x06 \x01(\x0b\x32\x1d.dialog.UpdateUserNameChangedH\x00\x12H\n\x1aupdateUserLocalNameChanged\x18\x07 \x01(\x0b\x32\".dialog.UpdateUserLocalNameChangedH\x00\x12\x46\n\x19updateUserContactsChanged\x18\x08 \x01(\x0b\x32!.dialog.UpdateUserContactsChangedH\x00\x12>\n\x15updateUserNickChanged\x18\t \x01(\x0b\x32\x1d.dialog.UpdateUserNickChangedH\x00\x12@\n\x16updateUserAboutChanged\x18\n \x01(\x0b\x32\x1e.dialog.UpdateUserAboutChangedH\x00\x12Z\n#updateUserPreferredLanguagesChanged\x18\x0b \x01(\x0b\x32+.dialog.UpdateUserPreferredLanguagesChangedH\x00\x12\x46\n\x19updateUserTimeZoneChanged\x18\x0c \x01(\x0b\x32!.dialog.UpdateUserTimeZoneChangedH\x00\x12L\n\x1cupdateUserBotCommandsChanged\x18\r \x01(\x0b\x32$.dialog.UpdateUserBotCommandsChangedH\x00\x12<\n\x14updateUserExtChanged\x18\x0e \x01(\x0b\x32\x1c.dialog.UpdateUserExtChangedH\x00\x12\x44\n\x18updateUserFullExtChanged\x18\x0f \x01(\x0b\x32 .dialog.UpdateUserFullExtChangedH\x00\x12<\n\x14updateUserSexChanged\x18\x10 \x01(\x0b\x32\x1c.dialog.UpdateUserSexChangedH\x00\x12P\n\x1eupdateUserCustomProfileChanged\x18\x11 \x01(\x0b\x32&.dialog.UpdateUserCustomProfileChangedH\x00\x12\x42\n\x17updateUserStatusChanged\x18\x12 \x01(\x0b\x32\x1f.dialog.UpdateUserStatusChangedH\x00\x12\x42\n\x17updateContactRegistered\x18\x13 \x01(\x0b\x32\x1f.dialog.UpdateContactRegisteredH\x00\x12:\n\x13updateContactsAdded\x18\x14 \x01(\x0b\x32\x1b.dialog.UpdateContactsAddedH\x00\x12P\n\x1eupdateContactsAddTaskSuspended\x18\x15 \x01(\x0b\x32&.dialog.UpdateContactsAddTaskSuspendedH\x00\x12>\n\x15updateContactsRemoved\x18\x16 \x01(\x0b\x32\x1d.dialog.UpdateContactsRemovedH\x00\x12\x36\n\x11updateUserBlocked\x18\x17 \x01(\x0b\x32\x19.dialog.UpdateUserBlockedH\x00\x12:\n\x13updateUserUnblocked\x18\x18 \x01(\x0b\x32\x1b.dialog.UpdateUserUnblockedH\x00\x12J\n\x1bupdateInteractiveMediaEvent\x18\x19 \x01(\x0b\x32#.dialog.UpdateInteractiveMediaEventH\x00\x12.\n\rupdateMessage\x18\x1a \x01(\x0b\x32\x15.dialog.UpdateMessageH\x00\x12J\n\x1bupdateMessageContentChanged\x18\x1b \x01(\x0b\x32#.dialog.UpdateMessageContentChangedH\x00\x12\x36\n\x11updateMessageSent\x18\x1c \x01(\x0b\x32\x19.dialog.UpdateMessageSentH\x00\x12>\n\x15updateMessageReceived\x18\x1d \x01(\x0b\x32\x1d.dialog.UpdateMessageReceivedH\x00\x12\x36\n\x11updateMessageRead\x18\x1e \x01(\x0b\x32\x19.dialog.UpdateMessageReadH\x00\x12>\n\x15updateMessageReadByMe\x18\x1f \x01(\x0b\x32\x1d.dialog.UpdateMessageReadByMeH\x00\x12:\n\x13updateMessageDelete\x18  \x01(\x0b\x32\x1b.dialog.UpdateMessageDeleteH\x00\x12\x32\n\x0fupdateChatClear\x18! \x01(\x0b\x32\x17.dialog.UpdateChatClearH\x00\x12\x34\n\x10updateChatDelete\x18\" \x01(\x0b\x32\x18.dialog.UpdateChatDeleteH\x00\x12\x36\n\x11updateChatArchive\x18# \x01(\x0b\x32\x19.dialog.UpdateChatArchiveH\x00\x12\x42\n\x17updateChatGroupsChanged\x18$ \x01(\x0b\x32\x1f.dialog.UpdateChatGroupsChangedH\x00\x12>\n\x15updateReactionsUpdate\x18% \x01(\x0b\x32\x1d.dialog.UpdateReactionsUpdateH\x00\x12L\n\x1cupdateDialogFavouriteChanged\x18& \x01(\x0b\x32$.dialog.UpdateDialogFavouriteChangedH\x00\x12J\n\x1bupdatePinnedMessagesChanged\x18\' \x01(\x0b\x32#.dialog.UpdatePinnedMessagesChangedH\x00\x12\x42\n\x17updateGroupTitleChanged\x18( \x01(\x0b\x32\x1f.dialog.UpdateGroupTitleChangedH\x00\x12\x44\n\x18updateGroupAvatarChanged\x18) \x01(\x0b\x32 .dialog.UpdateGroupAvatarChangedH\x00\x12\x42\n\x17updateGroupAboutChanged\x18+ \x01(\x0b\x32\x1f.dialog.UpdateGroupAboutChangedH\x00\x12\x42\n\x17updateGroupOwnerChanged\x18, \x01(\x0b\x32\x1f.dialog.UpdateGroupOwnerChangedH\x00\x12\x46\n\x19updateGroupMembersUpdated\x18\x33 \x01(\x0b\x32!.dialog.UpdateGroupMembersUpdatedH\x00\x12>\n\x15updateGroupMemberDiff\x18\x34 \x01(\x0b\x32\x1d.dialog.UpdateGroupMemberDiffH\x00\x12P\n\x1eupdateGroupMembersCountChanged\x18\x35 \x01(\x0b\x32&.dialog.UpdateGroupMembersCountChangedH\x00\x12Z\n#updateGroupMemberPermissionsChanged\x18\x37 \x01(\x0b\x32+.dialog.UpdateGroupMemberPermissionsChangedH\x00\x12\x46\n\x19updateGroupInviteObsolete\x18\x38 \x01(\x0b\x32!.dialog.UpdateGroupInviteObsoleteH\x00\x12P\n\x1eupdateGroupUserInvitedObsolete\x18\x39 \x01(\x0b\x32&.dialog.UpdateGroupUserInvitedObsoleteH\x00\x12L\n\x1cupdateGroupUserLeaveObsolete\x18: \x01(\x0b\x32$.dialog.UpdateGroupUserLeaveObsoleteH\x00\x12J\n\x1bupdateGroupUserKickObsolete\x18; \x01(\x0b\x32#.dialog.UpdateGroupUserKickObsoleteH\x00\x12T\n updateGroupMembersUpdateObsolete\x18< \x01(\x0b\x32(.dialog.UpdateGroupMembersUpdateObsoleteH\x00\x12R\n\x1fupdateGroupTitleChangedObsolete\x18= \x01(\x0b\x32\'.dialog.UpdateGroupTitleChangedObsoleteH\x00\x12R\n\x1fupdateGroupAboutChangedObsolete\x18? \x01(\x0b\x32\'.dialog.UpdateGroupAboutChangedObsoleteH\x00\x12T\n updateGroupAvatarChangedObsolete\x18@ \x01(\x0b\x32(.dialog.UpdateGroupAvatarChangedObsoleteH\x00\x12J\n\x1bupdateGroupShortnameChanged\x18\x41 \x01(\x0b\x32#.dialog.UpdateGroupShortnameChangedH\x00\x12R\n\x1fupdateStickerCollectionsChanged\x18\x42 \x01(\x0b\x32\'.dialog.UpdateStickerCollectionsChangedH\x00\x12\x44\n\x18updateStickerPackRemoved\x18\x43 \x01(\x0b\x32 .dialog.UpdateStickerPackRemovedH\x00\x12@\n\x16updateStickerPackAdded\x18\x44 \x01(\x0b\x32\x1e.dialog.UpdateStickerPackAddedH\x00\x12,\n\x0cupdateTyping\x18G \x01(\x0b\x32\x14.dialog.UpdateTypingH\x00\x12\x34\n\x10updateTypingStop\x18H \x01(\x0b\x32\x18.dialog.UpdateTypingStopH\x00\x12\x34\n\x10updateUserOnline\x18I \x01(\x0b\x32\x18.dialog.UpdateUserOnlineH\x00\x12\x36\n\x11updateUserOffline\x18J \x01(\x0b\x32\x19.dialog.UpdateUserOfflineH\x00\x12\x38\n\x12updateUserLastSeen\x18K \x01(\x0b\x32\x1a.dialog.UpdateUserLastSeenH\x00\x12\x36\n\x11updateGroupOnline\x18L \x01(\x0b\x32\x19.dialog.UpdateGroupOnlineH\x00\x12N\n\x1dupdateEventBusDeviceConnected\x18M \x01(\x0b\x32%.dialog.UpdateEventBusDeviceConnectedH\x00\x12T\n updateEventBusDeviceDisconnected\x18N \x01(\x0b\x32(.dialog.UpdateEventBusDeviceDisconnectedH\x00\x12>\n\x15updateEventBusMessage\x18O \x01(\x0b\x32\x1d.dialog.UpdateEventBusMessageH\x00\x12@\n\x16updateEventBusDisposed\x18P \x01(\x0b\x32\x1e.dialog.UpdateEventBusDisposedH\x00\x12L\n\x1cupdateIncomingCallDeprecated\x18Q \x01(\x0b\x32$.dialog.UpdateIncomingCallDeprecatedH\x00\x12\x38\n\x12updateIncomingCall\x18R \x01(\x0b\x32\x1a.dialog.UpdateIncomingCallH\x00\x12\x36\n\x11updateCallHandled\x18S \x01(\x0b\x32\x19.dialog.UpdateCallHandledH\x00\x12\x38\n\x12updateCallDisposed\x18T \x01(\x0b\x32\x1a.dialog.UpdateCallDisposedH\x00\x12@\n\x16updateParameterChanged\x18U \x01(\x0b\x32\x1e.dialog.UpdateParameterChangedH\x00\x12\x32\n\x0fupdateRawUpdate\x18V \x01(\x0b\x32\x17.dialog.UpdateRawUpdateH\x00\x12\x36\n\x11updateEmptyUpdate\x18W \x01(\x0b\x32\x19.dialog.UpdateEmptyUpdateH\x00\x12>\n\x15updateCountersChanged\x18X \x01(\x0b\x32\x1d.dialog.UpdateCountersChangedH\x00\x12,\n\x0cupdateConfig\x18Y \x01(\x0b\x32\x14.dialog.UpdateConfigH\x00\x12:\n\x13updateSpaceModified\x18Z \x01(\x0b\x32\x1b.dialog.UpdateSpaceModifiedH\x00\x12\x46\n\x19updateSpaceMemberModified\x18[ \x01(\x0b\x32!.dialog.UpdateSpaceMemberModifiedH\x00\x12J\n\x1bupdateMessageRejectedByHook\x18\\ \x01(\x0b\x32#.dialog.UpdateMessageRejectedByHookH\x00\x12R\n\x1fupdateMessageEditRejectedByHook\x18] \x01(\x0b\x32\'.dialog.UpdateMessageEditRejectedByHookH\x00\x12(\n\nupdateUser\x18^ \x01(\x0b\x32\x12.dialog.UpdateUserH\x00\x12\x44\n\x18updateFeatureFlagChanged\x18_ \x01(\x0b\x32 .dialog.UpdateFeatureFlagChangedH\x00\x12:\n\x13updateThreadCreated\x18` \x01(\x0b\x32\x1b.dialog.UpdateThreadCreatedH\x00\x12\x38\n\x12updateThreadLifted\x18\x61 \x01(\x0b\x32\x1a.dialog.UpdateThreadLiftedH\x00\x12*\n\x0bupdateGroup\x18\x62 \x01(\x0b\x32\x13.dialog.UpdateGroupH\x00\x12\x44\n\x18updateGroupMemberInvited\x18\x63 \x01(\x0b\x32 .dialog.UpdateGroupMemberInvitedH\x00\x12J\n\x16messageReactionsUpdate\x18\x64 \x01(\x0b\x32(.dialog.reactions.MessageReactionsUpdateH\x00\x12\x42\n\x17updatePermissionsChange\x18\x65 \x01(\x0b\x32\x1f.dialog.UpdatePermissionsChangeH\x00\x12\x36\n\x11updateGroupTyping\x18\x66 \x01(\x0b\x32\x19.dialog.UpdateGroupTypingH\x00\x12L\n\x1cupdateDialogReadLaterChanged\x18g \x01(\x0b\x32$.dialog.UpdateDialogReadLaterChangedH\x00\x42\x08\n\x06updateJ\x04\x08*\x10+J\x04\x08-\x10.J\x04\x08.\x10/J\x04\x08/\x10\x30J\x04\x08\x30\x10\x31J\x04\x08\x31\x10\x32J\x04\x08\x32\x10\x33J\x04\x08\x36\x10\x37J\x04\x08>\x10?J\x04\x08\x45\x10\x46J\x04\x08\x46\x10G\"\xed\x01\n\x12UpdateFatSeqUpdate\x12\x1a\n\x03seq\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\x12$\n\rupdate_header\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06update\x18\x04 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\x12*\n\x05users\x18\x05 \x03(\x0b\x32\x0c.dialog.UserB\r\x8a\xea\x30\t\n\x07\x63ompact\x12,\n\x06groups\x18\x06 \x03(\x0b\x32\r.dialog.GroupB\r\x8a\xea\x30\t\n\x07\x63ompact\"t\n\x10UpdateWeakUpdate\x12\x1b\n\x04\x64\x61te\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12$\n\rupdate_header\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06update\x18\x03 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\"\xd1\x01\n\x13UpdateWeakFatUpdate\x12\x1b\n\x04\x64\x61te\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12$\n\rupdate_header\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06update\x18\x03 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12*\n\x05users\x18\x04 \x03(\x0b\x32\x0c.dialog.UserB\r\x8a\xea\x30\t\n\x07visible\x12,\n\x06groups\x18\x05 \x03(\x0b\x32\r.dialog.GroupB\r\x8a\xea\x30\t\n\x07visible\"\x18\n\x16UpdateSeqUpdateTooLong\"V\n\x0fUpdateContainer\x12$\n\rupdate_header\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06update\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\"\xc2\x02\n\x14UpdateCombinedUpdate\x12 \n\tseq_start\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07seq_end\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x03 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12*\n\x05users\x18\x04 \x03(\x0b\x32\x0c.dialog.UserB\r\x8a\xea\x30\t\n\x07\x63ompact\x12,\n\x06groups\x18\x05 \x03(\x0b\x32\r.dialog.GroupB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x37\n\x07updates\x18\x06 \x03(\x0b\x32\x17.dialog.UpdateContainerB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\x08messages\x18\x07 \x03(\x0b\x32\x16.dialog.HistoryMessageB\r\x8a\xea\x30\t\n\x07visible\"q\n\x0fRequestGetState\x12@\n\roptimizations\x18\x01 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xf1\x01\n\x14RequestGetDifference\x12\x1a\n\x03seq\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07\x63ompact\x12@\n\roptimizations\x18\x03 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0b\x63onfig_hash\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xeb\x02\n\x15ResponseGetDifference\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x0c\x12(\n\x07updates\x18\x04 \x03(\x0b\x32\x17.dialog.UpdateSeqUpdate\x12(\n\x08messages\x18\x07 \x03(\x0b\x32\x16.dialog.HistoryMessage\x12\x11\n\tneed_more\x18\x05 \x01(\x08\x12\'\n\nusers_refs\x18\x08 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12)\n\x0bgroups_refs\x18\t \x03(\x0b\x32\x14.dialog.GroupOutPeer\x12\x1e\n\x06\x63onfig\x18\n \x01(\x0b\x32\x0e.dialog.Config\x12\x30\n\x0b\x63onfig_hash\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponseJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07\"Y\n\x1bRequestGetDialogsDifference\x12\x1c\n\x05\x63lock\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xb2\x01\n\x1cResponseGetDialogsDifference\x12\x1f\n\x07\x64ialogs\x18\x01 \x03(\x0b\x32\x0e.dialog.Dialog\x12)\n\x0bgroup_peers\x18\x02 \x03(\x0b\x32\x14.dialog.GroupOutPeer\x12\'\n\nuser_peers\x18\x03 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"p\n\x12GroupMembersSubset\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12!\n\nmember_ids\x18\x02 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x97\x02\n\x1dRequestGetReferencedEntitites\x12\x31\n\x05users\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact\x12.\n\x04mids\x18\x03 \x03(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12@\n\rgroup_members\x18\x04 \x03(\x0b\x32\x1a.dialog.GroupMembersSubsetB\r\x8a\xea\x30\t\n\x07visible\x12\x33\n\x06groups\x18\x05 \x03(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa5\x01\n\x1eResponseGetReferencedEntitites\x12\x1b\n\x05users\x18\x01 \x03(\x0b\x32\x0c.dialog.User\x12\x1d\n\x06groups\x18\x02 \x03(\x0b\x32\r.dialog.Group\x12(\n\x08messages\x18\x03 \x03(\x0b\x32\x16.dialog.HistoryMessage:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xe3\x01\n\x19RequestGetPartialPeerInfo\x12\x31\n\x05users\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x33\n\x06groups\x18\x02 \x03(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12@\n\rgroup_members\x18\x03 \x03(\x0b\x32\x1a.dialog.GroupMembersSubsetB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xab\x01\n\x1aResponseGetPartialPeerInfo\x12\x35\n\x05users\x18\x01 \x03(\x0b\x32\x17.dialog.UserPartialInfoB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\x06groups\x18\x02 \x03(\x0b\x32\x18.dialog.GroupPartialInfoB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"j\n\x0fUpdateRawUpdate\x12\x39\n\x04type\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x62ytes\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\"\x13\n\x11UpdateEmptyUpdate\"k\n\x18RequestSubscribeToOnline\x12\x31\n\x05users\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"m\n\x1aRequestSubscribeFromOnline\x12\x31\n\x05users\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x89\x01\n\x1dRequestSubscribeToGroupOnline\x12\x33\n\x06groups\x18\x01 \x03(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x15\n\rsend_users_id\x18\x02 \x01(\x08:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"t\n\x1fRequestSubscribeFromGroupOnline\x12\x33\n\x06groups\x18\x01 \x03(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x88\x01\n\x0cSeqUpdateBox\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x0c\x12+\n\x06update\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValue\x12/\n\x0eunboxed_update\x18\x04 \x01(\x0b\x32\x17.dialog.UpdateSeqUpdate\"(\n\tPeersList\x12\x1b\n\x05peers\x18\x01 \x03(\x0b\x32\x0c.dialog.Peer\"\xa3\x06\n\x11WeakUpdateCommand\x12\x44\n\x10\x63hange_my_online\x18\x01 \x01(\x0b\x32(.dialog.WeakUpdateCommand.ChangeMyOnlineH\x00\x12L\n\x14subscribe_to_onlines\x18\x02 \x01(\x0b\x32,.dialog.WeakUpdateCommand.SubscribeToOnlinesH\x00\x12\x35\n\x18unsubscribe_from_onlines\x18\x03 \x01(\x0b\x32\x11.dialog.PeersListH\x00\x12>\n\x1cunsubscribe_from_all_onlines\x18\x04 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x44\n\x10\x63hange_my_typing\x18\x05 \x01(\x0b\x32(.dialog.WeakUpdateCommand.ChangeMyTypingH\x00\x12\x31\n\x14subscribe_to_typings\x18\x06 \x01(\x0b\x32\x11.dialog.PeersListH\x00\x12\x35\n\x18unsubscribe_from_typings\x18\x07 \x01(\x0b\x32\x11.dialog.PeersListH\x00\x12>\n\x1cunsubscribe_from_all_typings\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x1aZ\n\x0e\x43hangeMyOnline\x12\x0e\n\x06online\x18\x01 \x01(\x08\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\x12\'\n\x0b\x64\x65vice_type\x18\x03 \x01(\x0e\x32\x12.dialog.DeviceType\x1aM\n\x12SubscribeToOnlines\x12 \n\x05peers\x18\x01 \x01(\x0b\x32\x11.dialog.PeersList\x12\x15\n\rsend_users_id\x18\x02 \x01(\x08\x1a]\n\x0e\x43hangeMyTyping\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.dialog.TypingType\x12\r\n\x05start\x18\x03 \x01(\x08\x42\t\n\x07\x63ommand\"\xe1\t\n\rWeakUpdateBox\x12&\n\x06typing\x18\x01 \x01(\x0b\x32\x14.dialog.UpdateTypingH\x00\x12/\n\x0btyping_stop\x18\x02 \x01(\x0b\x32\x18.dialog.UpdateTypingStopH\x00\x12\x34\n\x0euser_last_seen\x18\x03 \x01(\x0b\x32\x1a.dialog.UpdateUserLastSeenH\x00\x12\x31\n\x0cgroup_online\x18\x04 \x01(\x0b\x32\x19.dialog.UpdateGroupOnlineH\x00\x12\x44\n\x0c\x66orce_reload\x18\x05 \x01(\x0b\x32,.dialog.WeakUpdateBox.UpdateForceReloadStateH\x00\x12=\n\x12permissions_change\x18\x06 \x01(\x0b\x32\x1f.dialog.UpdatePermissionsChangeH\x00\x12=\n\x12user_status_change\x18\x07 \x01(\x0b\x32\x1f.dialog.UpdateUserStatusChangedH\x00\x12K\n\x17message_reaction_update\x18\x08 \x01(\x0b\x32(.dialog.reactions.MessageReactionsUpdateH\x00\x12(\n\x07message\x18\t \x01(\x0b\x32\x15.dialog.UpdateMessageH\x00\x12\x45\n\x16message_content_change\x18\n \x01(\x0b\x32#.dialog.UpdateMessageContentChangedH\x00\x12\x31\n\x0cmessage_read\x18\x0b \x01(\x0b\x32\x19.dialog.UpdateMessageReadH\x00\x12\x39\n\x10message_received\x18\x0c \x01(\x0b\x32\x1d.dialog.UpdateMessageReceivedH\x00\x12;\n\x12message_read_by_me\x18\r \x01(\x0b\x32\x1d.dialog.UpdateMessageReadByMeH\x00\x12/\n\x0buser_online\x18\x0e \x01(\x0b\x32\x18.dialog.UpdateUserOnlineH\x00\x12\x31\n\x0cgroup_typing\x18\x0f \x01(\x0b\x32\x19.dialog.UpdateGroupTypingH\x00\x12)\n\x08mini_app\x18\x10 \x01(\x0b\x32\x15.dialog.UpdateMiniAppH\x00\x12+\n\x05\x65vent\x18\x11 \x01(\x0b\x32\x1a.dialog.events.UpdateEventH\x00\x1a\x97\x02\n\x16UpdateForceReloadState\x12M\n\x06\x66ields\x18\x01 \x03(\x0b\x32=.dialog.WeakUpdateBox.UpdateForceReloadState.ForceReloadField\x1a\xad\x01\n\x10\x46orceReloadField\x12\x30\n\x0ereload_dialogs\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x31\n\x0freload_contacts\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12+\n\x0ereload_history\x18\x03 \x01(\x0b\x32\x11.dialog.PeersListH\x00\x42\x07\n\x05\x66ieldB\x0b\n\tupdatebox2\xe1\x0b\n\x12SequenceAndUpdates\x12i\n\x08GetState\x12\x17.dialog.RequestGetState\x1a\x13.dialog.ResponseSeq\"/\x82\xd3\xe4\x93\x02)\"$/v1/grpc/SequenceAndUpdates/GetState:\x01*\x12\x82\x01\n\rGetDifference\x12\x1c.dialog.RequestGetDifference\x1a\x1d.dialog.ResponseGetDifference\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/SequenceAndUpdates/GetDifference:\x01*\x12\x9e\x01\n\x14GetDialogsDifference\x12#.dialog.RequestGetDialogsDifference\x1a$.dialog.ResponseGetDialogsDifference\";\x82\xd3\xe4\x93\x02\x35\"0/v1/grpc/SequenceAndUpdates/GetDialogsDifference:\x01*\x12\xa6\x01\n\x16GetReferencedEntitites\x12%.dialog.RequestGetReferencedEntitites\x1a&.dialog.ResponseGetReferencedEntitites\"=\x82\xd3\xe4\x93\x02\x37\"2/v1/grpc/SequenceAndUpdates/GetReferencedEntitites:\x01*\x12]\n\x12GetPartialPeerInfo\x12!.dialog.RequestGetPartialPeerInfo\x1a\".dialog.ResponseGetPartialPeerInfo\"\x00\x12\x85\x01\n\x11SubscribeToOnline\x12 .dialog.RequestSubscribeToOnline\x1a\x14.dialog.ResponseVoid\"8\x82\xd3\xe4\x93\x02\x32\"-/v1/grpc/SequenceAndUpdates/SubscribeToOnline:\x01*\x12\x8b\x01\n\x13SubscribeFromOnline\x12\".dialog.RequestSubscribeFromOnline\x1a\x14.dialog.ResponseVoid\":\x82\xd3\xe4\x93\x02\x34\"//v1/grpc/SequenceAndUpdates/SubscribeFromOnline:\x01*\x12\x94\x01\n\x16SubscribeToGroupOnline\x12%.dialog.RequestSubscribeToGroupOnline\x1a\x14.dialog.ResponseVoid\"=\x82\xd3\xe4\x93\x02\x37\"2/v1/grpc/SequenceAndUpdates/SubscribeToGroupOnline:\x01*\x12\x9a\x01\n\x18SubscribeFromGroupOnline\x12\'.dialog.RequestSubscribeFromGroupOnline\x1a\x14.dialog.ResponseVoid\"?\x82\xd3\xe4\x93\x02\x39\"4/v1/grpc/SequenceAndUpdates/SubscribeFromGroupOnline:\x01*\x12o\n\nSeqUpdates\x12\x16.google.protobuf.Empty\x1a\x14.dialog.SeqUpdateBox\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/SequenceAndUpdates/SeqUpdates:\x01*0\x01\x12w\n\x0bWeakUpdates\x12\x19.dialog.WeakUpdateCommand\x1a\x15.dialog.WeakUpdateBox\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/SequenceAndUpdates/WeakUpdates:\x01*(\x01\x30\x01\x42\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,authentication__pb2.DESCRIPTOR,groups__pb2.DESCRIPTOR,stickers__pb2.DESCRIPTOR,presence__pb2.DESCRIPTOR,event__bus__pb2.DESCRIPTOR,web__rtc__pb2.DESCRIPTOR,config__sync__pb2.DESCRIPTOR,counters__pb2.DESCRIPTOR,contacts__pb2.DESCRIPTOR,privacy__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,messaging__pb2.DESCRIPTOR,users__pb2.DESCRIPTOR,spaces__pb2.DESCRIPTOR,reactions__pb2.DESCRIPTOR,permissions__pb2.DESCRIPTOR,events__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,miniappsregistry__pb2.DESCRIPTOR,])




_UPDATESEQUPDATE = _descriptor.Descriptor(
  name='UpdateSeqUpdate',
  full_name='dialog.UpdateSeqUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.UpdateSeqUpdate.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.UpdateSeqUpdate.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_header', full_name='dialog.UpdateSeqUpdate.update_header', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateForceReloadState', full_name='dialog.UpdateSeqUpdate.updateForceReloadState', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserAvatarChanged', full_name='dialog.UpdateSeqUpdate.updateUserAvatarChanged', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserNameChanged', full_name='dialog.UpdateSeqUpdate.updateUserNameChanged', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserLocalNameChanged', full_name='dialog.UpdateSeqUpdate.updateUserLocalNameChanged', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserContactsChanged', full_name='dialog.UpdateSeqUpdate.updateUserContactsChanged', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserNickChanged', full_name='dialog.UpdateSeqUpdate.updateUserNickChanged', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserAboutChanged', full_name='dialog.UpdateSeqUpdate.updateUserAboutChanged', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserPreferredLanguagesChanged', full_name='dialog.UpdateSeqUpdate.updateUserPreferredLanguagesChanged', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserTimeZoneChanged', full_name='dialog.UpdateSeqUpdate.updateUserTimeZoneChanged', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserBotCommandsChanged', full_name='dialog.UpdateSeqUpdate.updateUserBotCommandsChanged', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserExtChanged', full_name='dialog.UpdateSeqUpdate.updateUserExtChanged', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserFullExtChanged', full_name='dialog.UpdateSeqUpdate.updateUserFullExtChanged', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserSexChanged', full_name='dialog.UpdateSeqUpdate.updateUserSexChanged', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserCustomProfileChanged', full_name='dialog.UpdateSeqUpdate.updateUserCustomProfileChanged', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserStatusChanged', full_name='dialog.UpdateSeqUpdate.updateUserStatusChanged', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateContactRegistered', full_name='dialog.UpdateSeqUpdate.updateContactRegistered', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateContactsAdded', full_name='dialog.UpdateSeqUpdate.updateContactsAdded', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateContactsAddTaskSuspended', full_name='dialog.UpdateSeqUpdate.updateContactsAddTaskSuspended', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateContactsRemoved', full_name='dialog.UpdateSeqUpdate.updateContactsRemoved', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserBlocked', full_name='dialog.UpdateSeqUpdate.updateUserBlocked', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserUnblocked', full_name='dialog.UpdateSeqUpdate.updateUserUnblocked', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateInteractiveMediaEvent', full_name='dialog.UpdateSeqUpdate.updateInteractiveMediaEvent', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessage', full_name='dialog.UpdateSeqUpdate.updateMessage', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageContentChanged', full_name='dialog.UpdateSeqUpdate.updateMessageContentChanged', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageSent', full_name='dialog.UpdateSeqUpdate.updateMessageSent', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageReceived', full_name='dialog.UpdateSeqUpdate.updateMessageReceived', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageRead', full_name='dialog.UpdateSeqUpdate.updateMessageRead', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageReadByMe', full_name='dialog.UpdateSeqUpdate.updateMessageReadByMe', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageDelete', full_name='dialog.UpdateSeqUpdate.updateMessageDelete', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateChatClear', full_name='dialog.UpdateSeqUpdate.updateChatClear', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateChatDelete', full_name='dialog.UpdateSeqUpdate.updateChatDelete', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateChatArchive', full_name='dialog.UpdateSeqUpdate.updateChatArchive', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateChatGroupsChanged', full_name='dialog.UpdateSeqUpdate.updateChatGroupsChanged', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateReactionsUpdate', full_name='dialog.UpdateSeqUpdate.updateReactionsUpdate', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateDialogFavouriteChanged', full_name='dialog.UpdateSeqUpdate.updateDialogFavouriteChanged', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updatePinnedMessagesChanged', full_name='dialog.UpdateSeqUpdate.updatePinnedMessagesChanged', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupTitleChanged', full_name='dialog.UpdateSeqUpdate.updateGroupTitleChanged', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupAvatarChanged', full_name='dialog.UpdateSeqUpdate.updateGroupAvatarChanged', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupAboutChanged', full_name='dialog.UpdateSeqUpdate.updateGroupAboutChanged', index=41,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupOwnerChanged', full_name='dialog.UpdateSeqUpdate.updateGroupOwnerChanged', index=42,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupMembersUpdated', full_name='dialog.UpdateSeqUpdate.updateGroupMembersUpdated', index=43,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupMemberDiff', full_name='dialog.UpdateSeqUpdate.updateGroupMemberDiff', index=44,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupMembersCountChanged', full_name='dialog.UpdateSeqUpdate.updateGroupMembersCountChanged', index=45,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupMemberPermissionsChanged', full_name='dialog.UpdateSeqUpdate.updateGroupMemberPermissionsChanged', index=46,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupInviteObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupInviteObsolete', index=47,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupUserInvitedObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupUserInvitedObsolete', index=48,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupUserLeaveObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupUserLeaveObsolete', index=49,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupUserKickObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupUserKickObsolete', index=50,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupMembersUpdateObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupMembersUpdateObsolete', index=51,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupTitleChangedObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupTitleChangedObsolete', index=52,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupAboutChangedObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupAboutChangedObsolete', index=53,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupAvatarChangedObsolete', full_name='dialog.UpdateSeqUpdate.updateGroupAvatarChangedObsolete', index=54,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupShortnameChanged', full_name='dialog.UpdateSeqUpdate.updateGroupShortnameChanged', index=55,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateStickerCollectionsChanged', full_name='dialog.UpdateSeqUpdate.updateStickerCollectionsChanged', index=56,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateStickerPackRemoved', full_name='dialog.UpdateSeqUpdate.updateStickerPackRemoved', index=57,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateStickerPackAdded', full_name='dialog.UpdateSeqUpdate.updateStickerPackAdded', index=58,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTyping', full_name='dialog.UpdateSeqUpdate.updateTyping', index=59,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTypingStop', full_name='dialog.UpdateSeqUpdate.updateTypingStop', index=60,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserOnline', full_name='dialog.UpdateSeqUpdate.updateUserOnline', index=61,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserOffline', full_name='dialog.UpdateSeqUpdate.updateUserOffline', index=62,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUserLastSeen', full_name='dialog.UpdateSeqUpdate.updateUserLastSeen', index=63,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupOnline', full_name='dialog.UpdateSeqUpdate.updateGroupOnline', index=64,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateEventBusDeviceConnected', full_name='dialog.UpdateSeqUpdate.updateEventBusDeviceConnected', index=65,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateEventBusDeviceDisconnected', full_name='dialog.UpdateSeqUpdate.updateEventBusDeviceDisconnected', index=66,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateEventBusMessage', full_name='dialog.UpdateSeqUpdate.updateEventBusMessage', index=67,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateEventBusDisposed', full_name='dialog.UpdateSeqUpdate.updateEventBusDisposed', index=68,
      number=80, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateIncomingCallDeprecated', full_name='dialog.UpdateSeqUpdate.updateIncomingCallDeprecated', index=69,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateIncomingCall', full_name='dialog.UpdateSeqUpdate.updateIncomingCall', index=70,
      number=82, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateCallHandled', full_name='dialog.UpdateSeqUpdate.updateCallHandled', index=71,
      number=83, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateCallDisposed', full_name='dialog.UpdateSeqUpdate.updateCallDisposed', index=72,
      number=84, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateParameterChanged', full_name='dialog.UpdateSeqUpdate.updateParameterChanged', index=73,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateRawUpdate', full_name='dialog.UpdateSeqUpdate.updateRawUpdate', index=74,
      number=86, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateEmptyUpdate', full_name='dialog.UpdateSeqUpdate.updateEmptyUpdate', index=75,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateCountersChanged', full_name='dialog.UpdateSeqUpdate.updateCountersChanged', index=76,
      number=88, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateConfig', full_name='dialog.UpdateSeqUpdate.updateConfig', index=77,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateSpaceModified', full_name='dialog.UpdateSeqUpdate.updateSpaceModified', index=78,
      number=90, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateSpaceMemberModified', full_name='dialog.UpdateSeqUpdate.updateSpaceMemberModified', index=79,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageRejectedByHook', full_name='dialog.UpdateSeqUpdate.updateMessageRejectedByHook', index=80,
      number=92, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateMessageEditRejectedByHook', full_name='dialog.UpdateSeqUpdate.updateMessageEditRejectedByHook', index=81,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateUser', full_name='dialog.UpdateSeqUpdate.updateUser', index=82,
      number=94, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateFeatureFlagChanged', full_name='dialog.UpdateSeqUpdate.updateFeatureFlagChanged', index=83,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateThreadCreated', full_name='dialog.UpdateSeqUpdate.updateThreadCreated', index=84,
      number=96, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateThreadLifted', full_name='dialog.UpdateSeqUpdate.updateThreadLifted', index=85,
      number=97, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroup', full_name='dialog.UpdateSeqUpdate.updateGroup', index=86,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupMemberInvited', full_name='dialog.UpdateSeqUpdate.updateGroupMemberInvited', index=87,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messageReactionsUpdate', full_name='dialog.UpdateSeqUpdate.messageReactionsUpdate', index=88,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updatePermissionsChange', full_name='dialog.UpdateSeqUpdate.updatePermissionsChange', index=89,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateGroupTyping', full_name='dialog.UpdateSeqUpdate.updateGroupTyping', index=90,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateDialogReadLaterChanged', full_name='dialog.UpdateSeqUpdate.updateDialogReadLaterChanged', index=91,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='update', full_name='dialog.UpdateSeqUpdate.update',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=490,
  serialized_end=6673,
)


_UPDATEFATSEQUPDATE = _descriptor.Descriptor(
  name='UpdateFatSeqUpdate',
  full_name='dialog.UpdateFatSeqUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.UpdateFatSeqUpdate.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.UpdateFatSeqUpdate.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_header', full_name='dialog.UpdateFatSeqUpdate.update_header', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='dialog.UpdateFatSeqUpdate.update', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.UpdateFatSeqUpdate.users', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.UpdateFatSeqUpdate.groups', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6676,
  serialized_end=6913,
)


_UPDATEWEAKUPDATE = _descriptor.Descriptor(
  name='UpdateWeakUpdate',
  full_name='dialog.UpdateWeakUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateWeakUpdate.date', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_header', full_name='dialog.UpdateWeakUpdate.update_header', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='dialog.UpdateWeakUpdate.update', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6915,
  serialized_end=7031,
)


_UPDATEWEAKFATUPDATE = _descriptor.Descriptor(
  name='UpdateWeakFatUpdate',
  full_name='dialog.UpdateWeakFatUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateWeakFatUpdate.date', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_header', full_name='dialog.UpdateWeakFatUpdate.update_header', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='dialog.UpdateWeakFatUpdate.update', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.UpdateWeakFatUpdate.users', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.UpdateWeakFatUpdate.groups', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7034,
  serialized_end=7243,
)


_UPDATESEQUPDATETOOLONG = _descriptor.Descriptor(
  name='UpdateSeqUpdateTooLong',
  full_name='dialog.UpdateSeqUpdateTooLong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7245,
  serialized_end=7269,
)


_UPDATECONTAINER = _descriptor.Descriptor(
  name='UpdateContainer',
  full_name='dialog.UpdateContainer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_header', full_name='dialog.UpdateContainer.update_header', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='dialog.UpdateContainer.update', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7271,
  serialized_end=7357,
)


_UPDATECOMBINEDUPDATE = _descriptor.Descriptor(
  name='UpdateCombinedUpdate',
  full_name='dialog.UpdateCombinedUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq_start', full_name='dialog.UpdateCombinedUpdate.seq_start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq_end', full_name='dialog.UpdateCombinedUpdate.seq_end', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.UpdateCombinedUpdate.state', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.UpdateCombinedUpdate.users', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.UpdateCombinedUpdate.groups', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='dialog.UpdateCombinedUpdate.updates', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='dialog.UpdateCombinedUpdate.messages', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7360,
  serialized_end=7682,
)


_REQUESTGETSTATE = _descriptor.Descriptor(
  name='RequestGetState',
  full_name='dialog.RequestGetState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestGetState.optimizations', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7684,
  serialized_end=7797,
)


_REQUESTGETDIFFERENCE = _descriptor.Descriptor(
  name='RequestGetDifference',
  full_name='dialog.RequestGetDifference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.RequestGetDifference.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.RequestGetDifference.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestGetDifference.optimizations', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_hash', full_name='dialog.RequestGetDifference.config_hash', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7800,
  serialized_end=8041,
)


_RESPONSEGETDIFFERENCE = _descriptor.Descriptor(
  name='ResponseGetDifference',
  full_name='dialog.ResponseGetDifference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseGetDifference.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseGetDifference.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='dialog.ResponseGetDifference.updates', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='dialog.ResponseGetDifference.messages', index=3,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_more', full_name='dialog.ResponseGetDifference.need_more', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users_refs', full_name='dialog.ResponseGetDifference.users_refs', index=5,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups_refs', full_name='dialog.ResponseGetDifference.groups_refs', index=6,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='dialog.ResponseGetDifference.config', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_hash', full_name='dialog.ResponseGetDifference.config_hash', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8044,
  serialized_end=8407,
)


_REQUESTGETDIALOGSDIFFERENCE = _descriptor.Descriptor(
  name='RequestGetDialogsDifference',
  full_name='dialog.RequestGetDialogsDifference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestGetDialogsDifference.clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8409,
  serialized_end=8498,
)


_RESPONSEGETDIALOGSDIFFERENCE = _descriptor.Descriptor(
  name='ResponseGetDialogsDifference',
  full_name='dialog.ResponseGetDialogsDifference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialogs', full_name='dialog.ResponseGetDialogsDifference.dialogs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_peers', full_name='dialog.ResponseGetDialogsDifference.group_peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseGetDialogsDifference.user_peers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8501,
  serialized_end=8679,
)


_GROUPMEMBERSSUBSET = _descriptor.Descriptor(
  name='GroupMembersSubset',
  full_name='dialog.GroupMembersSubset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.GroupMembersSubset.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member_ids', full_name='dialog.GroupMembersSubset.member_ids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8681,
  serialized_end=8793,
)


_REQUESTGETREFERENCEDENTITITES = _descriptor.Descriptor(
  name='RequestGetReferencedEntitites',
  full_name='dialog.RequestGetReferencedEntitites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.RequestGetReferencedEntitites.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mids', full_name='dialog.RequestGetReferencedEntitites.mids', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_members', full_name='dialog.RequestGetReferencedEntitites.group_members', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.RequestGetReferencedEntitites.groups', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8796,
  serialized_end=9075,
)


_RESPONSEGETREFERENCEDENTITITES = _descriptor.Descriptor(
  name='ResponseGetReferencedEntitites',
  full_name='dialog.ResponseGetReferencedEntitites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseGetReferencedEntitites.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseGetReferencedEntitites.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='dialog.ResponseGetReferencedEntitites.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9078,
  serialized_end=9243,
)


_REQUESTGETPARTIALPEERINFO = _descriptor.Descriptor(
  name='RequestGetPartialPeerInfo',
  full_name='dialog.RequestGetPartialPeerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.RequestGetPartialPeerInfo.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.RequestGetPartialPeerInfo.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_members', full_name='dialog.RequestGetPartialPeerInfo.group_members', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9246,
  serialized_end=9473,
)


_RESPONSEGETPARTIALPEERINFO = _descriptor.Descriptor(
  name='ResponseGetPartialPeerInfo',
  full_name='dialog.ResponseGetPartialPeerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseGetPartialPeerInfo.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseGetPartialPeerInfo.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9476,
  serialized_end=9647,
)


_UPDATERAWUPDATE = _descriptor.Descriptor(
  name='UpdateRawUpdate',
  full_name='dialog.UpdateRawUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.UpdateRawUpdate.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='dialog.UpdateRawUpdate.bytes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9649,
  serialized_end=9755,
)


_UPDATEEMPTYUPDATE = _descriptor.Descriptor(
  name='UpdateEmptyUpdate',
  full_name='dialog.UpdateEmptyUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9757,
  serialized_end=9776,
)


_REQUESTSUBSCRIBETOONLINE = _descriptor.Descriptor(
  name='RequestSubscribeToOnline',
  full_name='dialog.RequestSubscribeToOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.RequestSubscribeToOnline.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9778,
  serialized_end=9885,
)


_REQUESTSUBSCRIBEFROMONLINE = _descriptor.Descriptor(
  name='RequestSubscribeFromOnline',
  full_name='dialog.RequestSubscribeFromOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.RequestSubscribeFromOnline.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9887,
  serialized_end=9996,
)


_REQUESTSUBSCRIBETOGROUPONLINE = _descriptor.Descriptor(
  name='RequestSubscribeToGroupOnline',
  full_name='dialog.RequestSubscribeToGroupOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.RequestSubscribeToGroupOnline.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_users_id', full_name='dialog.RequestSubscribeToGroupOnline.send_users_id', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9999,
  serialized_end=10136,
)


_REQUESTSUBSCRIBEFROMGROUPONLINE = _descriptor.Descriptor(
  name='RequestSubscribeFromGroupOnline',
  full_name='dialog.RequestSubscribeFromGroupOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.RequestSubscribeFromGroupOnline.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10138,
  serialized_end=10254,
)


_SEQUPDATEBOX = _descriptor.Descriptor(
  name='SeqUpdateBox',
  full_name='dialog.SeqUpdateBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.SeqUpdateBox.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.SeqUpdateBox.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='dialog.SeqUpdateBox.update', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unboxed_update', full_name='dialog.SeqUpdateBox.unboxed_update', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10257,
  serialized_end=10393,
)


_PEERSLIST = _descriptor.Descriptor(
  name='PeersList',
  full_name='dialog.PeersList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='dialog.PeersList.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10395,
  serialized_end=10435,
)


_WEAKUPDATECOMMAND_CHANGEMYONLINE = _descriptor.Descriptor(
  name='ChangeMyOnline',
  full_name='dialog.WeakUpdateCommand.ChangeMyOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='online', full_name='dialog.WeakUpdateCommand.ChangeMyOnline.online', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.WeakUpdateCommand.ChangeMyOnline.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='dialog.WeakUpdateCommand.ChangeMyOnline.device_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10966,
  serialized_end=11056,
)

_WEAKUPDATECOMMAND_SUBSCRIBETOONLINES = _descriptor.Descriptor(
  name='SubscribeToOnlines',
  full_name='dialog.WeakUpdateCommand.SubscribeToOnlines',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='dialog.WeakUpdateCommand.SubscribeToOnlines.peers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_users_id', full_name='dialog.WeakUpdateCommand.SubscribeToOnlines.send_users_id', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11058,
  serialized_end=11135,
)

_WEAKUPDATECOMMAND_CHANGEMYTYPING = _descriptor.Descriptor(
  name='ChangeMyTyping',
  full_name='dialog.WeakUpdateCommand.ChangeMyTyping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.WeakUpdateCommand.ChangeMyTyping.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.WeakUpdateCommand.ChangeMyTyping.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='dialog.WeakUpdateCommand.ChangeMyTyping.start', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11137,
  serialized_end=11230,
)

_WEAKUPDATECOMMAND = _descriptor.Descriptor(
  name='WeakUpdateCommand',
  full_name='dialog.WeakUpdateCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_my_online', full_name='dialog.WeakUpdateCommand.change_my_online', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribe_to_onlines', full_name='dialog.WeakUpdateCommand.subscribe_to_onlines', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_from_onlines', full_name='dialog.WeakUpdateCommand.unsubscribe_from_onlines', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_from_all_onlines', full_name='dialog.WeakUpdateCommand.unsubscribe_from_all_onlines', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_my_typing', full_name='dialog.WeakUpdateCommand.change_my_typing', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribe_to_typings', full_name='dialog.WeakUpdateCommand.subscribe_to_typings', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_from_typings', full_name='dialog.WeakUpdateCommand.unsubscribe_from_typings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_from_all_typings', full_name='dialog.WeakUpdateCommand.unsubscribe_from_all_typings', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEAKUPDATECOMMAND_CHANGEMYONLINE, _WEAKUPDATECOMMAND_SUBSCRIBETOONLINES, _WEAKUPDATECOMMAND_CHANGEMYTYPING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='dialog.WeakUpdateCommand.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10438,
  serialized_end=11241,
)


_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD = _descriptor.Descriptor(
  name='ForceReloadField',
  full_name='dialog.WeakUpdateBox.UpdateForceReloadState.ForceReloadField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reload_dialogs', full_name='dialog.WeakUpdateBox.UpdateForceReloadState.ForceReloadField.reload_dialogs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reload_contacts', full_name='dialog.WeakUpdateBox.UpdateForceReloadState.ForceReloadField.reload_contacts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reload_history', full_name='dialog.WeakUpdateBox.UpdateForceReloadState.ForceReloadField.reload_history', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='field', full_name='dialog.WeakUpdateBox.UpdateForceReloadState.ForceReloadField.field',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12307,
  serialized_end=12480,
)

_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE = _descriptor.Descriptor(
  name='UpdateForceReloadState',
  full_name='dialog.WeakUpdateBox.UpdateForceReloadState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='dialog.WeakUpdateBox.UpdateForceReloadState.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12201,
  serialized_end=12480,
)

_WEAKUPDATEBOX = _descriptor.Descriptor(
  name='WeakUpdateBox',
  full_name='dialog.WeakUpdateBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='typing', full_name='dialog.WeakUpdateBox.typing', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typing_stop', full_name='dialog.WeakUpdateBox.typing_stop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_last_seen', full_name='dialog.WeakUpdateBox.user_last_seen', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_online', full_name='dialog.WeakUpdateBox.group_online', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force_reload', full_name='dialog.WeakUpdateBox.force_reload', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions_change', full_name='dialog.WeakUpdateBox.permissions_change', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_status_change', full_name='dialog.WeakUpdateBox.user_status_change', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_reaction_update', full_name='dialog.WeakUpdateBox.message_reaction_update', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.WeakUpdateBox.message', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_content_change', full_name='dialog.WeakUpdateBox.message_content_change', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_read', full_name='dialog.WeakUpdateBox.message_read', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_received', full_name='dialog.WeakUpdateBox.message_received', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_read_by_me', full_name='dialog.WeakUpdateBox.message_read_by_me', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_online', full_name='dialog.WeakUpdateBox.user_online', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_typing', full_name='dialog.WeakUpdateBox.group_typing', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mini_app', full_name='dialog.WeakUpdateBox.mini_app', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='dialog.WeakUpdateBox.event', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='updatebox', full_name='dialog.WeakUpdateBox.updatebox',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11244,
  serialized_end=12493,
)

_UPDATESEQUPDATE.fields_by_name['updateForceReloadState'].message_type = authentication__pb2._UPDATEFORCERELOADSTATE
_UPDATESEQUPDATE.fields_by_name['updateUserAvatarChanged'].message_type = users__pb2._UPDATEUSERAVATARCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserNameChanged'].message_type = users__pb2._UPDATEUSERNAMECHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserLocalNameChanged'].message_type = users__pb2._UPDATEUSERLOCALNAMECHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserContactsChanged'].message_type = users__pb2._UPDATEUSERCONTACTSCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserNickChanged'].message_type = users__pb2._UPDATEUSERNICKCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserAboutChanged'].message_type = users__pb2._UPDATEUSERABOUTCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserPreferredLanguagesChanged'].message_type = users__pb2._UPDATEUSERPREFERREDLANGUAGESCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserTimeZoneChanged'].message_type = users__pb2._UPDATEUSERTIMEZONECHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserBotCommandsChanged'].message_type = users__pb2._UPDATEUSERBOTCOMMANDSCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserExtChanged'].message_type = users__pb2._UPDATEUSEREXTCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserFullExtChanged'].message_type = users__pb2._UPDATEUSERFULLEXTCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserSexChanged'].message_type = users__pb2._UPDATEUSERSEXCHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserCustomProfileChanged'].message_type = users__pb2._UPDATEUSERCUSTOMPROFILECHANGED
_UPDATESEQUPDATE.fields_by_name['updateUserStatusChanged'].message_type = users__pb2._UPDATEUSERSTATUSCHANGED
_UPDATESEQUPDATE.fields_by_name['updateContactRegistered'].message_type = contacts__pb2._UPDATECONTACTREGISTERED
_UPDATESEQUPDATE.fields_by_name['updateContactsAdded'].message_type = contacts__pb2._UPDATECONTACTSADDED
_UPDATESEQUPDATE.fields_by_name['updateContactsAddTaskSuspended'].message_type = contacts__pb2._UPDATECONTACTSADDTASKSUSPENDED
_UPDATESEQUPDATE.fields_by_name['updateContactsRemoved'].message_type = contacts__pb2._UPDATECONTACTSREMOVED
_UPDATESEQUPDATE.fields_by_name['updateUserBlocked'].message_type = privacy__pb2._UPDATEUSERBLOCKED
_UPDATESEQUPDATE.fields_by_name['updateUserUnblocked'].message_type = privacy__pb2._UPDATEUSERUNBLOCKED
_UPDATESEQUPDATE.fields_by_name['updateInteractiveMediaEvent'].message_type = messaging__pb2._UPDATEINTERACTIVEMEDIAEVENT
_UPDATESEQUPDATE.fields_by_name['updateMessage'].message_type = messaging__pb2._UPDATEMESSAGE
_UPDATESEQUPDATE.fields_by_name['updateMessageContentChanged'].message_type = messaging__pb2._UPDATEMESSAGECONTENTCHANGED
_UPDATESEQUPDATE.fields_by_name['updateMessageSent'].message_type = messaging__pb2._UPDATEMESSAGESENT
_UPDATESEQUPDATE.fields_by_name['updateMessageReceived'].message_type = messaging__pb2._UPDATEMESSAGERECEIVED
_UPDATESEQUPDATE.fields_by_name['updateMessageRead'].message_type = messaging__pb2._UPDATEMESSAGEREAD
_UPDATESEQUPDATE.fields_by_name['updateMessageReadByMe'].message_type = messaging__pb2._UPDATEMESSAGEREADBYME
_UPDATESEQUPDATE.fields_by_name['updateMessageDelete'].message_type = messaging__pb2._UPDATEMESSAGEDELETE
_UPDATESEQUPDATE.fields_by_name['updateChatClear'].message_type = messaging__pb2._UPDATECHATCLEAR
_UPDATESEQUPDATE.fields_by_name['updateChatDelete'].message_type = messaging__pb2._UPDATECHATDELETE
_UPDATESEQUPDATE.fields_by_name['updateChatArchive'].message_type = messaging__pb2._UPDATECHATARCHIVE
_UPDATESEQUPDATE.fields_by_name['updateChatGroupsChanged'].message_type = messaging__pb2._UPDATECHATGROUPSCHANGED
_UPDATESEQUPDATE.fields_by_name['updateReactionsUpdate'].message_type = messaging__pb2._UPDATEREACTIONSUPDATE
_UPDATESEQUPDATE.fields_by_name['updateDialogFavouriteChanged'].message_type = messaging__pb2._UPDATEDIALOGFAVOURITECHANGED
_UPDATESEQUPDATE.fields_by_name['updatePinnedMessagesChanged'].message_type = messaging__pb2._UPDATEPINNEDMESSAGESCHANGED
_UPDATESEQUPDATE.fields_by_name['updateGroupTitleChanged'].message_type = groups__pb2._UPDATEGROUPTITLECHANGED
_UPDATESEQUPDATE.fields_by_name['updateGroupAvatarChanged'].message_type = groups__pb2._UPDATEGROUPAVATARCHANGED
_UPDATESEQUPDATE.fields_by_name['updateGroupAboutChanged'].message_type = groups__pb2._UPDATEGROUPABOUTCHANGED
_UPDATESEQUPDATE.fields_by_name['updateGroupOwnerChanged'].message_type = groups__pb2._UPDATEGROUPOWNERCHANGED
_UPDATESEQUPDATE.fields_by_name['updateGroupMembersUpdated'].message_type = groups__pb2._UPDATEGROUPMEMBERSUPDATED
_UPDATESEQUPDATE.fields_by_name['updateGroupMemberDiff'].message_type = groups__pb2._UPDATEGROUPMEMBERDIFF
_UPDATESEQUPDATE.fields_by_name['updateGroupMembersCountChanged'].message_type = groups__pb2._UPDATEGROUPMEMBERSCOUNTCHANGED
_UPDATESEQUPDATE.fields_by_name['updateGroupMemberPermissionsChanged'].message_type = groups__pb2._UPDATEGROUPMEMBERPERMISSIONSCHANGED
_UPDATESEQUPDATE.fields_by_name['updateGroupInviteObsolete'].message_type = groups__pb2._UPDATEGROUPINVITEOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupUserInvitedObsolete'].message_type = groups__pb2._UPDATEGROUPUSERINVITEDOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupUserLeaveObsolete'].message_type = groups__pb2._UPDATEGROUPUSERLEAVEOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupUserKickObsolete'].message_type = groups__pb2._UPDATEGROUPUSERKICKOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupMembersUpdateObsolete'].message_type = groups__pb2._UPDATEGROUPMEMBERSUPDATEOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupTitleChangedObsolete'].message_type = groups__pb2._UPDATEGROUPTITLECHANGEDOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupAboutChangedObsolete'].message_type = groups__pb2._UPDATEGROUPABOUTCHANGEDOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupAvatarChangedObsolete'].message_type = groups__pb2._UPDATEGROUPAVATARCHANGEDOBSOLETE
_UPDATESEQUPDATE.fields_by_name['updateGroupShortnameChanged'].message_type = groups__pb2._UPDATEGROUPSHORTNAMECHANGED
_UPDATESEQUPDATE.fields_by_name['updateStickerCollectionsChanged'].message_type = stickers__pb2._UPDATESTICKERCOLLECTIONSCHANGED
_UPDATESEQUPDATE.fields_by_name['updateStickerPackRemoved'].message_type = stickers__pb2._UPDATESTICKERPACKREMOVED
_UPDATESEQUPDATE.fields_by_name['updateStickerPackAdded'].message_type = stickers__pb2._UPDATESTICKERPACKADDED
_UPDATESEQUPDATE.fields_by_name['updateTyping'].message_type = presence__pb2._UPDATETYPING
_UPDATESEQUPDATE.fields_by_name['updateTypingStop'].message_type = presence__pb2._UPDATETYPINGSTOP
_UPDATESEQUPDATE.fields_by_name['updateUserOnline'].message_type = presence__pb2._UPDATEUSERONLINE
_UPDATESEQUPDATE.fields_by_name['updateUserOffline'].message_type = presence__pb2._UPDATEUSEROFFLINE
_UPDATESEQUPDATE.fields_by_name['updateUserLastSeen'].message_type = presence__pb2._UPDATEUSERLASTSEEN
_UPDATESEQUPDATE.fields_by_name['updateGroupOnline'].message_type = presence__pb2._UPDATEGROUPONLINE
_UPDATESEQUPDATE.fields_by_name['updateEventBusDeviceConnected'].message_type = event__bus__pb2._UPDATEEVENTBUSDEVICECONNECTED
_UPDATESEQUPDATE.fields_by_name['updateEventBusDeviceDisconnected'].message_type = event__bus__pb2._UPDATEEVENTBUSDEVICEDISCONNECTED
_UPDATESEQUPDATE.fields_by_name['updateEventBusMessage'].message_type = event__bus__pb2._UPDATEEVENTBUSMESSAGE
_UPDATESEQUPDATE.fields_by_name['updateEventBusDisposed'].message_type = event__bus__pb2._UPDATEEVENTBUSDISPOSED
_UPDATESEQUPDATE.fields_by_name['updateIncomingCallDeprecated'].message_type = web__rtc__pb2._UPDATEINCOMINGCALLDEPRECATED
_UPDATESEQUPDATE.fields_by_name['updateIncomingCall'].message_type = web__rtc__pb2._UPDATEINCOMINGCALL
_UPDATESEQUPDATE.fields_by_name['updateCallHandled'].message_type = web__rtc__pb2._UPDATECALLHANDLED
_UPDATESEQUPDATE.fields_by_name['updateCallDisposed'].message_type = web__rtc__pb2._UPDATECALLDISPOSED
_UPDATESEQUPDATE.fields_by_name['updateParameterChanged'].message_type = config__sync__pb2._UPDATEPARAMETERCHANGED
_UPDATESEQUPDATE.fields_by_name['updateRawUpdate'].message_type = _UPDATERAWUPDATE
_UPDATESEQUPDATE.fields_by_name['updateEmptyUpdate'].message_type = _UPDATEEMPTYUPDATE
_UPDATESEQUPDATE.fields_by_name['updateCountersChanged'].message_type = counters__pb2._UPDATECOUNTERSCHANGED
_UPDATESEQUPDATE.fields_by_name['updateConfig'].message_type = miscellaneous__pb2._UPDATECONFIG
_UPDATESEQUPDATE.fields_by_name['updateSpaceModified'].message_type = spaces__pb2._UPDATESPACEMODIFIED
_UPDATESEQUPDATE.fields_by_name['updateSpaceMemberModified'].message_type = spaces__pb2._UPDATESPACEMEMBERMODIFIED
_UPDATESEQUPDATE.fields_by_name['updateMessageRejectedByHook'].message_type = messaging__pb2._UPDATEMESSAGEREJECTEDBYHOOK
_UPDATESEQUPDATE.fields_by_name['updateMessageEditRejectedByHook'].message_type = messaging__pb2._UPDATEMESSAGEEDITREJECTEDBYHOOK
_UPDATESEQUPDATE.fields_by_name['updateUser'].message_type = users__pb2._UPDATEUSER
_UPDATESEQUPDATE.fields_by_name['updateFeatureFlagChanged'].message_type = config__sync__pb2._UPDATEFEATUREFLAGCHANGED
_UPDATESEQUPDATE.fields_by_name['updateThreadCreated'].message_type = messaging__pb2._UPDATETHREADCREATED
_UPDATESEQUPDATE.fields_by_name['updateThreadLifted'].message_type = messaging__pb2._UPDATETHREADLIFTED
_UPDATESEQUPDATE.fields_by_name['updateGroup'].message_type = groups__pb2._UPDATEGROUP
_UPDATESEQUPDATE.fields_by_name['updateGroupMemberInvited'].message_type = groups__pb2._UPDATEGROUPMEMBERINVITED
_UPDATESEQUPDATE.fields_by_name['messageReactionsUpdate'].message_type = reactions__pb2._MESSAGEREACTIONSUPDATE
_UPDATESEQUPDATE.fields_by_name['updatePermissionsChange'].message_type = permissions__pb2._UPDATEPERMISSIONSCHANGE
_UPDATESEQUPDATE.fields_by_name['updateGroupTyping'].message_type = presence__pb2._UPDATEGROUPTYPING
_UPDATESEQUPDATE.fields_by_name['updateDialogReadLaterChanged'].message_type = messaging__pb2._UPDATEDIALOGREADLATERCHANGED
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateForceReloadState'])
_UPDATESEQUPDATE.fields_by_name['updateForceReloadState'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserAvatarChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserAvatarChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserNameChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserNameChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserLocalNameChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserLocalNameChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserContactsChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserContactsChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserNickChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserNickChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserAboutChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserAboutChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserPreferredLanguagesChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserPreferredLanguagesChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserTimeZoneChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserTimeZoneChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserBotCommandsChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserBotCommandsChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserExtChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserExtChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserFullExtChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserFullExtChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserSexChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserSexChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserCustomProfileChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserCustomProfileChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserStatusChanged'])
_UPDATESEQUPDATE.fields_by_name['updateUserStatusChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateContactRegistered'])
_UPDATESEQUPDATE.fields_by_name['updateContactRegistered'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateContactsAdded'])
_UPDATESEQUPDATE.fields_by_name['updateContactsAdded'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateContactsAddTaskSuspended'])
_UPDATESEQUPDATE.fields_by_name['updateContactsAddTaskSuspended'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateContactsRemoved'])
_UPDATESEQUPDATE.fields_by_name['updateContactsRemoved'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserBlocked'])
_UPDATESEQUPDATE.fields_by_name['updateUserBlocked'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserUnblocked'])
_UPDATESEQUPDATE.fields_by_name['updateUserUnblocked'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateInteractiveMediaEvent'])
_UPDATESEQUPDATE.fields_by_name['updateInteractiveMediaEvent'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessage'])
_UPDATESEQUPDATE.fields_by_name['updateMessage'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageContentChanged'])
_UPDATESEQUPDATE.fields_by_name['updateMessageContentChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageSent'])
_UPDATESEQUPDATE.fields_by_name['updateMessageSent'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageReceived'])
_UPDATESEQUPDATE.fields_by_name['updateMessageReceived'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageRead'])
_UPDATESEQUPDATE.fields_by_name['updateMessageRead'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageReadByMe'])
_UPDATESEQUPDATE.fields_by_name['updateMessageReadByMe'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageDelete'])
_UPDATESEQUPDATE.fields_by_name['updateMessageDelete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateChatClear'])
_UPDATESEQUPDATE.fields_by_name['updateChatClear'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateChatDelete'])
_UPDATESEQUPDATE.fields_by_name['updateChatDelete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateChatArchive'])
_UPDATESEQUPDATE.fields_by_name['updateChatArchive'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateChatGroupsChanged'])
_UPDATESEQUPDATE.fields_by_name['updateChatGroupsChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateReactionsUpdate'])
_UPDATESEQUPDATE.fields_by_name['updateReactionsUpdate'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateDialogFavouriteChanged'])
_UPDATESEQUPDATE.fields_by_name['updateDialogFavouriteChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updatePinnedMessagesChanged'])
_UPDATESEQUPDATE.fields_by_name['updatePinnedMessagesChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupTitleChanged'])
_UPDATESEQUPDATE.fields_by_name['updateGroupTitleChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupAvatarChanged'])
_UPDATESEQUPDATE.fields_by_name['updateGroupAvatarChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupAboutChanged'])
_UPDATESEQUPDATE.fields_by_name['updateGroupAboutChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupOwnerChanged'])
_UPDATESEQUPDATE.fields_by_name['updateGroupOwnerChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupMembersUpdated'])
_UPDATESEQUPDATE.fields_by_name['updateGroupMembersUpdated'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupMemberDiff'])
_UPDATESEQUPDATE.fields_by_name['updateGroupMemberDiff'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupMembersCountChanged'])
_UPDATESEQUPDATE.fields_by_name['updateGroupMembersCountChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupMemberPermissionsChanged'])
_UPDATESEQUPDATE.fields_by_name['updateGroupMemberPermissionsChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupInviteObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupInviteObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupUserInvitedObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupUserInvitedObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupUserLeaveObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupUserLeaveObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupUserKickObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupUserKickObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupMembersUpdateObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupMembersUpdateObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupTitleChangedObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupTitleChangedObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupAboutChangedObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupAboutChangedObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupAvatarChangedObsolete'])
_UPDATESEQUPDATE.fields_by_name['updateGroupAvatarChangedObsolete'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupShortnameChanged'])
_UPDATESEQUPDATE.fields_by_name['updateGroupShortnameChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateStickerCollectionsChanged'])
_UPDATESEQUPDATE.fields_by_name['updateStickerCollectionsChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateStickerPackRemoved'])
_UPDATESEQUPDATE.fields_by_name['updateStickerPackRemoved'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateStickerPackAdded'])
_UPDATESEQUPDATE.fields_by_name['updateStickerPackAdded'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateTyping'])
_UPDATESEQUPDATE.fields_by_name['updateTyping'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateTypingStop'])
_UPDATESEQUPDATE.fields_by_name['updateTypingStop'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserOnline'])
_UPDATESEQUPDATE.fields_by_name['updateUserOnline'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserOffline'])
_UPDATESEQUPDATE.fields_by_name['updateUserOffline'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUserLastSeen'])
_UPDATESEQUPDATE.fields_by_name['updateUserLastSeen'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupOnline'])
_UPDATESEQUPDATE.fields_by_name['updateGroupOnline'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateEventBusDeviceConnected'])
_UPDATESEQUPDATE.fields_by_name['updateEventBusDeviceConnected'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateEventBusDeviceDisconnected'])
_UPDATESEQUPDATE.fields_by_name['updateEventBusDeviceDisconnected'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateEventBusMessage'])
_UPDATESEQUPDATE.fields_by_name['updateEventBusMessage'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateEventBusDisposed'])
_UPDATESEQUPDATE.fields_by_name['updateEventBusDisposed'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateIncomingCallDeprecated'])
_UPDATESEQUPDATE.fields_by_name['updateIncomingCallDeprecated'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateIncomingCall'])
_UPDATESEQUPDATE.fields_by_name['updateIncomingCall'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateCallHandled'])
_UPDATESEQUPDATE.fields_by_name['updateCallHandled'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateCallDisposed'])
_UPDATESEQUPDATE.fields_by_name['updateCallDisposed'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateParameterChanged'])
_UPDATESEQUPDATE.fields_by_name['updateParameterChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateRawUpdate'])
_UPDATESEQUPDATE.fields_by_name['updateRawUpdate'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateEmptyUpdate'])
_UPDATESEQUPDATE.fields_by_name['updateEmptyUpdate'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateCountersChanged'])
_UPDATESEQUPDATE.fields_by_name['updateCountersChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateConfig'])
_UPDATESEQUPDATE.fields_by_name['updateConfig'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateSpaceModified'])
_UPDATESEQUPDATE.fields_by_name['updateSpaceModified'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateSpaceMemberModified'])
_UPDATESEQUPDATE.fields_by_name['updateSpaceMemberModified'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageRejectedByHook'])
_UPDATESEQUPDATE.fields_by_name['updateMessageRejectedByHook'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateMessageEditRejectedByHook'])
_UPDATESEQUPDATE.fields_by_name['updateMessageEditRejectedByHook'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateUser'])
_UPDATESEQUPDATE.fields_by_name['updateUser'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateFeatureFlagChanged'])
_UPDATESEQUPDATE.fields_by_name['updateFeatureFlagChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateThreadCreated'])
_UPDATESEQUPDATE.fields_by_name['updateThreadCreated'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateThreadLifted'])
_UPDATESEQUPDATE.fields_by_name['updateThreadLifted'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroup'])
_UPDATESEQUPDATE.fields_by_name['updateGroup'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupMemberInvited'])
_UPDATESEQUPDATE.fields_by_name['updateGroupMemberInvited'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['messageReactionsUpdate'])
_UPDATESEQUPDATE.fields_by_name['messageReactionsUpdate'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updatePermissionsChange'])
_UPDATESEQUPDATE.fields_by_name['updatePermissionsChange'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateGroupTyping'])
_UPDATESEQUPDATE.fields_by_name['updateGroupTyping'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATESEQUPDATE.oneofs_by_name['update'].fields.append(
  _UPDATESEQUPDATE.fields_by_name['updateDialogReadLaterChanged'])
_UPDATESEQUPDATE.fields_by_name['updateDialogReadLaterChanged'].containing_oneof = _UPDATESEQUPDATE.oneofs_by_name['update']
_UPDATEFATSEQUPDATE.fields_by_name['users'].message_type = users__pb2._USER
_UPDATEFATSEQUPDATE.fields_by_name['groups'].message_type = groups__pb2._GROUP
_UPDATEWEAKFATUPDATE.fields_by_name['users'].message_type = users__pb2._USER
_UPDATEWEAKFATUPDATE.fields_by_name['groups'].message_type = groups__pb2._GROUP
_UPDATECOMBINEDUPDATE.fields_by_name['users'].message_type = users__pb2._USER
_UPDATECOMBINEDUPDATE.fields_by_name['groups'].message_type = groups__pb2._GROUP
_UPDATECOMBINEDUPDATE.fields_by_name['updates'].message_type = _UPDATECONTAINER
_UPDATECOMBINEDUPDATE.fields_by_name['messages'].message_type = messaging__pb2._HISTORYMESSAGE
_REQUESTGETSTATE.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTGETDIFFERENCE.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTGETDIFFERENCE.fields_by_name['config_hash'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RESPONSEGETDIFFERENCE.fields_by_name['updates'].message_type = _UPDATESEQUPDATE
_RESPONSEGETDIFFERENCE.fields_by_name['messages'].message_type = messaging__pb2._HISTORYMESSAGE
_RESPONSEGETDIFFERENCE.fields_by_name['users_refs'].message_type = peers__pb2._USEROUTPEER
_RESPONSEGETDIFFERENCE.fields_by_name['groups_refs'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSEGETDIFFERENCE.fields_by_name['config'].message_type = miscellaneous__pb2._CONFIG
_RESPONSEGETDIFFERENCE.fields_by_name['config_hash'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RESPONSEGETDIALOGSDIFFERENCE.fields_by_name['dialogs'].message_type = messaging__pb2._DIALOG
_RESPONSEGETDIALOGSDIFFERENCE.fields_by_name['group_peers'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSEGETDIALOGSDIFFERENCE.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_GROUPMEMBERSSUBSET.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTGETREFERENCEDENTITITES.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_REQUESTGETREFERENCEDENTITITES.fields_by_name['mids'].message_type = definitions__pb2._UUIDVALUE
_REQUESTGETREFERENCEDENTITITES.fields_by_name['group_members'].message_type = _GROUPMEMBERSSUBSET
_REQUESTGETREFERENCEDENTITITES.fields_by_name['groups'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSEGETREFERENCEDENTITITES.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSEGETREFERENCEDENTITITES.fields_by_name['groups'].message_type = groups__pb2._GROUP
_RESPONSEGETREFERENCEDENTITITES.fields_by_name['messages'].message_type = messaging__pb2._HISTORYMESSAGE
_REQUESTGETPARTIALPEERINFO.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_REQUESTGETPARTIALPEERINFO.fields_by_name['groups'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTGETPARTIALPEERINFO.fields_by_name['group_members'].message_type = _GROUPMEMBERSSUBSET
_RESPONSEGETPARTIALPEERINFO.fields_by_name['users'].message_type = users__pb2._USERPARTIALINFO
_RESPONSEGETPARTIALPEERINFO.fields_by_name['groups'].message_type = groups__pb2._GROUPPARTIALINFO
_UPDATERAWUPDATE.fields_by_name['type'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSUBSCRIBETOONLINE.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_REQUESTSUBSCRIBEFROMONLINE.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_REQUESTSUBSCRIBETOGROUPONLINE.fields_by_name['groups'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTSUBSCRIBEFROMGROUPONLINE.fields_by_name['groups'].message_type = peers__pb2._GROUPOUTPEER
_SEQUPDATEBOX.fields_by_name['update'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_SEQUPDATEBOX.fields_by_name['unboxed_update'].message_type = _UPDATESEQUPDATE
_PEERSLIST.fields_by_name['peers'].message_type = peers__pb2._PEER
_WEAKUPDATECOMMAND_CHANGEMYONLINE.fields_by_name['device_type'].enum_type = presence__pb2._DEVICETYPE
_WEAKUPDATECOMMAND_CHANGEMYONLINE.containing_type = _WEAKUPDATECOMMAND
_WEAKUPDATECOMMAND_SUBSCRIBETOONLINES.fields_by_name['peers'].message_type = _PEERSLIST
_WEAKUPDATECOMMAND_SUBSCRIBETOONLINES.containing_type = _WEAKUPDATECOMMAND
_WEAKUPDATECOMMAND_CHANGEMYTYPING.fields_by_name['peer'].message_type = peers__pb2._PEER
_WEAKUPDATECOMMAND_CHANGEMYTYPING.fields_by_name['type'].enum_type = presence__pb2._TYPINGTYPE
_WEAKUPDATECOMMAND_CHANGEMYTYPING.containing_type = _WEAKUPDATECOMMAND
_WEAKUPDATECOMMAND.fields_by_name['change_my_online'].message_type = _WEAKUPDATECOMMAND_CHANGEMYONLINE
_WEAKUPDATECOMMAND.fields_by_name['subscribe_to_onlines'].message_type = _WEAKUPDATECOMMAND_SUBSCRIBETOONLINES
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_onlines'].message_type = _PEERSLIST
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_all_onlines'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_WEAKUPDATECOMMAND.fields_by_name['change_my_typing'].message_type = _WEAKUPDATECOMMAND_CHANGEMYTYPING
_WEAKUPDATECOMMAND.fields_by_name['subscribe_to_typings'].message_type = _PEERSLIST
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_typings'].message_type = _PEERSLIST
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_all_typings'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['change_my_online'])
_WEAKUPDATECOMMAND.fields_by_name['change_my_online'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['subscribe_to_onlines'])
_WEAKUPDATECOMMAND.fields_by_name['subscribe_to_onlines'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_onlines'])
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_onlines'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_all_onlines'])
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_all_onlines'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['change_my_typing'])
_WEAKUPDATECOMMAND.fields_by_name['change_my_typing'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['subscribe_to_typings'])
_WEAKUPDATECOMMAND.fields_by_name['subscribe_to_typings'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_typings'])
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_typings'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_all_typings'])
_WEAKUPDATECOMMAND.fields_by_name['unsubscribe_from_all_typings'].containing_oneof = _WEAKUPDATECOMMAND.oneofs_by_name['command']
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_dialogs'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_contacts'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_history'].message_type = _PEERSLIST
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.containing_type = _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.oneofs_by_name['field'].fields.append(
  _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_dialogs'])
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_dialogs'].containing_oneof = _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.oneofs_by_name['field']
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.oneofs_by_name['field'].fields.append(
  _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_contacts'])
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_contacts'].containing_oneof = _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.oneofs_by_name['field']
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.oneofs_by_name['field'].fields.append(
  _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_history'])
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.fields_by_name['reload_history'].containing_oneof = _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD.oneofs_by_name['field']
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE.fields_by_name['fields'].message_type = _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD
_WEAKUPDATEBOX_UPDATEFORCERELOADSTATE.containing_type = _WEAKUPDATEBOX
_WEAKUPDATEBOX.fields_by_name['typing'].message_type = presence__pb2._UPDATETYPING
_WEAKUPDATEBOX.fields_by_name['typing_stop'].message_type = presence__pb2._UPDATETYPINGSTOP
_WEAKUPDATEBOX.fields_by_name['user_last_seen'].message_type = presence__pb2._UPDATEUSERLASTSEEN
_WEAKUPDATEBOX.fields_by_name['group_online'].message_type = presence__pb2._UPDATEGROUPONLINE
_WEAKUPDATEBOX.fields_by_name['force_reload'].message_type = _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE
_WEAKUPDATEBOX.fields_by_name['permissions_change'].message_type = permissions__pb2._UPDATEPERMISSIONSCHANGE
_WEAKUPDATEBOX.fields_by_name['user_status_change'].message_type = users__pb2._UPDATEUSERSTATUSCHANGED
_WEAKUPDATEBOX.fields_by_name['message_reaction_update'].message_type = reactions__pb2._MESSAGEREACTIONSUPDATE
_WEAKUPDATEBOX.fields_by_name['message'].message_type = messaging__pb2._UPDATEMESSAGE
_WEAKUPDATEBOX.fields_by_name['message_content_change'].message_type = messaging__pb2._UPDATEMESSAGECONTENTCHANGED
_WEAKUPDATEBOX.fields_by_name['message_read'].message_type = messaging__pb2._UPDATEMESSAGEREAD
_WEAKUPDATEBOX.fields_by_name['message_received'].message_type = messaging__pb2._UPDATEMESSAGERECEIVED
_WEAKUPDATEBOX.fields_by_name['message_read_by_me'].message_type = messaging__pb2._UPDATEMESSAGEREADBYME
_WEAKUPDATEBOX.fields_by_name['user_online'].message_type = presence__pb2._UPDATEUSERONLINE
_WEAKUPDATEBOX.fields_by_name['group_typing'].message_type = presence__pb2._UPDATEGROUPTYPING
_WEAKUPDATEBOX.fields_by_name['mini_app'].message_type = miniappsregistry__pb2._UPDATEMINIAPP
_WEAKUPDATEBOX.fields_by_name['event'].message_type = events__pb2._UPDATEEVENT
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['typing'])
_WEAKUPDATEBOX.fields_by_name['typing'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['typing_stop'])
_WEAKUPDATEBOX.fields_by_name['typing_stop'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['user_last_seen'])
_WEAKUPDATEBOX.fields_by_name['user_last_seen'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['group_online'])
_WEAKUPDATEBOX.fields_by_name['group_online'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['force_reload'])
_WEAKUPDATEBOX.fields_by_name['force_reload'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['permissions_change'])
_WEAKUPDATEBOX.fields_by_name['permissions_change'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['user_status_change'])
_WEAKUPDATEBOX.fields_by_name['user_status_change'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['message_reaction_update'])
_WEAKUPDATEBOX.fields_by_name['message_reaction_update'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['message'])
_WEAKUPDATEBOX.fields_by_name['message'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['message_content_change'])
_WEAKUPDATEBOX.fields_by_name['message_content_change'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['message_read'])
_WEAKUPDATEBOX.fields_by_name['message_read'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['message_received'])
_WEAKUPDATEBOX.fields_by_name['message_received'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['message_read_by_me'])
_WEAKUPDATEBOX.fields_by_name['message_read_by_me'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['user_online'])
_WEAKUPDATEBOX.fields_by_name['user_online'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['group_typing'])
_WEAKUPDATEBOX.fields_by_name['group_typing'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['mini_app'])
_WEAKUPDATEBOX.fields_by_name['mini_app'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
_WEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _WEAKUPDATEBOX.fields_by_name['event'])
_WEAKUPDATEBOX.fields_by_name['event'].containing_oneof = _WEAKUPDATEBOX.oneofs_by_name['updatebox']
DESCRIPTOR.message_types_by_name['UpdateSeqUpdate'] = _UPDATESEQUPDATE
DESCRIPTOR.message_types_by_name['UpdateFatSeqUpdate'] = _UPDATEFATSEQUPDATE
DESCRIPTOR.message_types_by_name['UpdateWeakUpdate'] = _UPDATEWEAKUPDATE
DESCRIPTOR.message_types_by_name['UpdateWeakFatUpdate'] = _UPDATEWEAKFATUPDATE
DESCRIPTOR.message_types_by_name['UpdateSeqUpdateTooLong'] = _UPDATESEQUPDATETOOLONG
DESCRIPTOR.message_types_by_name['UpdateContainer'] = _UPDATECONTAINER
DESCRIPTOR.message_types_by_name['UpdateCombinedUpdate'] = _UPDATECOMBINEDUPDATE
DESCRIPTOR.message_types_by_name['RequestGetState'] = _REQUESTGETSTATE
DESCRIPTOR.message_types_by_name['RequestGetDifference'] = _REQUESTGETDIFFERENCE
DESCRIPTOR.message_types_by_name['ResponseGetDifference'] = _RESPONSEGETDIFFERENCE
DESCRIPTOR.message_types_by_name['RequestGetDialogsDifference'] = _REQUESTGETDIALOGSDIFFERENCE
DESCRIPTOR.message_types_by_name['ResponseGetDialogsDifference'] = _RESPONSEGETDIALOGSDIFFERENCE
DESCRIPTOR.message_types_by_name['GroupMembersSubset'] = _GROUPMEMBERSSUBSET
DESCRIPTOR.message_types_by_name['RequestGetReferencedEntitites'] = _REQUESTGETREFERENCEDENTITITES
DESCRIPTOR.message_types_by_name['ResponseGetReferencedEntitites'] = _RESPONSEGETREFERENCEDENTITITES
DESCRIPTOR.message_types_by_name['RequestGetPartialPeerInfo'] = _REQUESTGETPARTIALPEERINFO
DESCRIPTOR.message_types_by_name['ResponseGetPartialPeerInfo'] = _RESPONSEGETPARTIALPEERINFO
DESCRIPTOR.message_types_by_name['UpdateRawUpdate'] = _UPDATERAWUPDATE
DESCRIPTOR.message_types_by_name['UpdateEmptyUpdate'] = _UPDATEEMPTYUPDATE
DESCRIPTOR.message_types_by_name['RequestSubscribeToOnline'] = _REQUESTSUBSCRIBETOONLINE
DESCRIPTOR.message_types_by_name['RequestSubscribeFromOnline'] = _REQUESTSUBSCRIBEFROMONLINE
DESCRIPTOR.message_types_by_name['RequestSubscribeToGroupOnline'] = _REQUESTSUBSCRIBETOGROUPONLINE
DESCRIPTOR.message_types_by_name['RequestSubscribeFromGroupOnline'] = _REQUESTSUBSCRIBEFROMGROUPONLINE
DESCRIPTOR.message_types_by_name['SeqUpdateBox'] = _SEQUPDATEBOX
DESCRIPTOR.message_types_by_name['PeersList'] = _PEERSLIST
DESCRIPTOR.message_types_by_name['WeakUpdateCommand'] = _WEAKUPDATECOMMAND
DESCRIPTOR.message_types_by_name['WeakUpdateBox'] = _WEAKUPDATEBOX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpdateSeqUpdate = _reflection.GeneratedProtocolMessageType('UpdateSeqUpdate', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESEQUPDATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateSeqUpdate)
  })
_sym_db.RegisterMessage(UpdateSeqUpdate)

UpdateFatSeqUpdate = _reflection.GeneratedProtocolMessageType('UpdateFatSeqUpdate', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFATSEQUPDATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateFatSeqUpdate)
  })
_sym_db.RegisterMessage(UpdateFatSeqUpdate)

UpdateWeakUpdate = _reflection.GeneratedProtocolMessageType('UpdateWeakUpdate', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEAKUPDATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateWeakUpdate)
  })
_sym_db.RegisterMessage(UpdateWeakUpdate)

UpdateWeakFatUpdate = _reflection.GeneratedProtocolMessageType('UpdateWeakFatUpdate', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEAKFATUPDATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateWeakFatUpdate)
  })
_sym_db.RegisterMessage(UpdateWeakFatUpdate)

UpdateSeqUpdateTooLong = _reflection.GeneratedProtocolMessageType('UpdateSeqUpdateTooLong', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESEQUPDATETOOLONG,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateSeqUpdateTooLong)
  })
_sym_db.RegisterMessage(UpdateSeqUpdateTooLong)

UpdateContainer = _reflection.GeneratedProtocolMessageType('UpdateContainer', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTAINER,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateContainer)
  })
_sym_db.RegisterMessage(UpdateContainer)

UpdateCombinedUpdate = _reflection.GeneratedProtocolMessageType('UpdateCombinedUpdate', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMBINEDUPDATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateCombinedUpdate)
  })
_sym_db.RegisterMessage(UpdateCombinedUpdate)

RequestGetState = _reflection.GeneratedProtocolMessageType('RequestGetState', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETSTATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetState)
  })
_sym_db.RegisterMessage(RequestGetState)

RequestGetDifference = _reflection.GeneratedProtocolMessageType('RequestGetDifference', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETDIFFERENCE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetDifference)
  })
_sym_db.RegisterMessage(RequestGetDifference)

ResponseGetDifference = _reflection.GeneratedProtocolMessageType('ResponseGetDifference', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETDIFFERENCE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetDifference)
  })
_sym_db.RegisterMessage(ResponseGetDifference)

RequestGetDialogsDifference = _reflection.GeneratedProtocolMessageType('RequestGetDialogsDifference', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETDIALOGSDIFFERENCE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetDialogsDifference)
  })
_sym_db.RegisterMessage(RequestGetDialogsDifference)

ResponseGetDialogsDifference = _reflection.GeneratedProtocolMessageType('ResponseGetDialogsDifference', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETDIALOGSDIFFERENCE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetDialogsDifference)
  })
_sym_db.RegisterMessage(ResponseGetDialogsDifference)

GroupMembersSubset = _reflection.GeneratedProtocolMessageType('GroupMembersSubset', (_message.Message,), {
  'DESCRIPTOR' : _GROUPMEMBERSSUBSET,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupMembersSubset)
  })
_sym_db.RegisterMessage(GroupMembersSubset)

RequestGetReferencedEntitites = _reflection.GeneratedProtocolMessageType('RequestGetReferencedEntitites', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETREFERENCEDENTITITES,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetReferencedEntitites)
  })
_sym_db.RegisterMessage(RequestGetReferencedEntitites)

ResponseGetReferencedEntitites = _reflection.GeneratedProtocolMessageType('ResponseGetReferencedEntitites', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETREFERENCEDENTITITES,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetReferencedEntitites)
  })
_sym_db.RegisterMessage(ResponseGetReferencedEntitites)

RequestGetPartialPeerInfo = _reflection.GeneratedProtocolMessageType('RequestGetPartialPeerInfo', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETPARTIALPEERINFO,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetPartialPeerInfo)
  })
_sym_db.RegisterMessage(RequestGetPartialPeerInfo)

ResponseGetPartialPeerInfo = _reflection.GeneratedProtocolMessageType('ResponseGetPartialPeerInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETPARTIALPEERINFO,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetPartialPeerInfo)
  })
_sym_db.RegisterMessage(ResponseGetPartialPeerInfo)

UpdateRawUpdate = _reflection.GeneratedProtocolMessageType('UpdateRawUpdate', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERAWUPDATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateRawUpdate)
  })
_sym_db.RegisterMessage(UpdateRawUpdate)

UpdateEmptyUpdate = _reflection.GeneratedProtocolMessageType('UpdateEmptyUpdate', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEMPTYUPDATE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEmptyUpdate)
  })
_sym_db.RegisterMessage(UpdateEmptyUpdate)

RequestSubscribeToOnline = _reflection.GeneratedProtocolMessageType('RequestSubscribeToOnline', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSUBSCRIBETOONLINE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSubscribeToOnline)
  })
_sym_db.RegisterMessage(RequestSubscribeToOnline)

RequestSubscribeFromOnline = _reflection.GeneratedProtocolMessageType('RequestSubscribeFromOnline', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSUBSCRIBEFROMONLINE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSubscribeFromOnline)
  })
_sym_db.RegisterMessage(RequestSubscribeFromOnline)

RequestSubscribeToGroupOnline = _reflection.GeneratedProtocolMessageType('RequestSubscribeToGroupOnline', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSUBSCRIBETOGROUPONLINE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSubscribeToGroupOnline)
  })
_sym_db.RegisterMessage(RequestSubscribeToGroupOnline)

RequestSubscribeFromGroupOnline = _reflection.GeneratedProtocolMessageType('RequestSubscribeFromGroupOnline', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSUBSCRIBEFROMGROUPONLINE,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSubscribeFromGroupOnline)
  })
_sym_db.RegisterMessage(RequestSubscribeFromGroupOnline)

SeqUpdateBox = _reflection.GeneratedProtocolMessageType('SeqUpdateBox', (_message.Message,), {
  'DESCRIPTOR' : _SEQUPDATEBOX,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SeqUpdateBox)
  })
_sym_db.RegisterMessage(SeqUpdateBox)

PeersList = _reflection.GeneratedProtocolMessageType('PeersList', (_message.Message,), {
  'DESCRIPTOR' : _PEERSLIST,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.PeersList)
  })
_sym_db.RegisterMessage(PeersList)

WeakUpdateCommand = _reflection.GeneratedProtocolMessageType('WeakUpdateCommand', (_message.Message,), {

  'ChangeMyOnline' : _reflection.GeneratedProtocolMessageType('ChangeMyOnline', (_message.Message,), {
    'DESCRIPTOR' : _WEAKUPDATECOMMAND_CHANGEMYONLINE,
    '__module__' : 'sequence_and_updates_pb2'
    # @@protoc_insertion_point(class_scope:dialog.WeakUpdateCommand.ChangeMyOnline)
    })
  ,

  'SubscribeToOnlines' : _reflection.GeneratedProtocolMessageType('SubscribeToOnlines', (_message.Message,), {
    'DESCRIPTOR' : _WEAKUPDATECOMMAND_SUBSCRIBETOONLINES,
    '__module__' : 'sequence_and_updates_pb2'
    # @@protoc_insertion_point(class_scope:dialog.WeakUpdateCommand.SubscribeToOnlines)
    })
  ,

  'ChangeMyTyping' : _reflection.GeneratedProtocolMessageType('ChangeMyTyping', (_message.Message,), {
    'DESCRIPTOR' : _WEAKUPDATECOMMAND_CHANGEMYTYPING,
    '__module__' : 'sequence_and_updates_pb2'
    # @@protoc_insertion_point(class_scope:dialog.WeakUpdateCommand.ChangeMyTyping)
    })
  ,
  'DESCRIPTOR' : _WEAKUPDATECOMMAND,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.WeakUpdateCommand)
  })
_sym_db.RegisterMessage(WeakUpdateCommand)
_sym_db.RegisterMessage(WeakUpdateCommand.ChangeMyOnline)
_sym_db.RegisterMessage(WeakUpdateCommand.SubscribeToOnlines)
_sym_db.RegisterMessage(WeakUpdateCommand.ChangeMyTyping)

WeakUpdateBox = _reflection.GeneratedProtocolMessageType('WeakUpdateBox', (_message.Message,), {

  'UpdateForceReloadState' : _reflection.GeneratedProtocolMessageType('UpdateForceReloadState', (_message.Message,), {

    'ForceReloadField' : _reflection.GeneratedProtocolMessageType('ForceReloadField', (_message.Message,), {
      'DESCRIPTOR' : _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE_FORCERELOADFIELD,
      '__module__' : 'sequence_and_updates_pb2'
      # @@protoc_insertion_point(class_scope:dialog.WeakUpdateBox.UpdateForceReloadState.ForceReloadField)
      })
    ,
    'DESCRIPTOR' : _WEAKUPDATEBOX_UPDATEFORCERELOADSTATE,
    '__module__' : 'sequence_and_updates_pb2'
    # @@protoc_insertion_point(class_scope:dialog.WeakUpdateBox.UpdateForceReloadState)
    })
  ,
  'DESCRIPTOR' : _WEAKUPDATEBOX,
  '__module__' : 'sequence_and_updates_pb2'
  # @@protoc_insertion_point(class_scope:dialog.WeakUpdateBox)
  })
_sym_db.RegisterMessage(WeakUpdateBox)
_sym_db.RegisterMessage(WeakUpdateBox.UpdateForceReloadState)
_sym_db.RegisterMessage(WeakUpdateBox.UpdateForceReloadState.ForceReloadField)


DESCRIPTOR._options = None
_UPDATESEQUPDATE.fields_by_name['seq']._options = None
_UPDATESEQUPDATE.fields_by_name['state']._options = None
_UPDATESEQUPDATE.fields_by_name['update_header']._options = None
_UPDATEFATSEQUPDATE.fields_by_name['seq']._options = None
_UPDATEFATSEQUPDATE.fields_by_name['state']._options = None
_UPDATEFATSEQUPDATE.fields_by_name['update_header']._options = None
_UPDATEFATSEQUPDATE.fields_by_name['update']._options = None
_UPDATEFATSEQUPDATE.fields_by_name['users']._options = None
_UPDATEFATSEQUPDATE.fields_by_name['groups']._options = None
_UPDATEWEAKUPDATE.fields_by_name['date']._options = None
_UPDATEWEAKUPDATE.fields_by_name['update_header']._options = None
_UPDATEWEAKUPDATE.fields_by_name['update']._options = None
_UPDATEWEAKFATUPDATE.fields_by_name['date']._options = None
_UPDATEWEAKFATUPDATE.fields_by_name['update_header']._options = None
_UPDATEWEAKFATUPDATE.fields_by_name['update']._options = None
_UPDATEWEAKFATUPDATE.fields_by_name['users']._options = None
_UPDATEWEAKFATUPDATE.fields_by_name['groups']._options = None
_UPDATECONTAINER.fields_by_name['update_header']._options = None
_UPDATECONTAINER.fields_by_name['update']._options = None
_UPDATECOMBINEDUPDATE.fields_by_name['seq_start']._options = None
_UPDATECOMBINEDUPDATE.fields_by_name['seq_end']._options = None
_UPDATECOMBINEDUPDATE.fields_by_name['state']._options = None
_UPDATECOMBINEDUPDATE.fields_by_name['users']._options = None
_UPDATECOMBINEDUPDATE.fields_by_name['groups']._options = None
_UPDATECOMBINEDUPDATE.fields_by_name['updates']._options = None
_UPDATECOMBINEDUPDATE.fields_by_name['messages']._options = None
_REQUESTGETSTATE.fields_by_name['optimizations']._options = None
_REQUESTGETSTATE._options = None
_REQUESTGETDIFFERENCE.fields_by_name['seq']._options = None
_REQUESTGETDIFFERENCE.fields_by_name['state']._options = None
_REQUESTGETDIFFERENCE.fields_by_name['optimizations']._options = None
_REQUESTGETDIFFERENCE.fields_by_name['config_hash']._options = None
_REQUESTGETDIFFERENCE._options = None
_RESPONSEGETDIFFERENCE._options = None
_REQUESTGETDIALOGSDIFFERENCE.fields_by_name['clock']._options = None
_REQUESTGETDIALOGSDIFFERENCE._options = None
_RESPONSEGETDIALOGSDIFFERENCE._options = None
_GROUPMEMBERSSUBSET.fields_by_name['group_peer']._options = None
_GROUPMEMBERSSUBSET.fields_by_name['member_ids']._options = None
_REQUESTGETREFERENCEDENTITITES.fields_by_name['users']._options = None
_REQUESTGETREFERENCEDENTITITES.fields_by_name['mids']._options = None
_REQUESTGETREFERENCEDENTITITES.fields_by_name['group_members']._options = None
_REQUESTGETREFERENCEDENTITITES.fields_by_name['groups']._options = None
_REQUESTGETREFERENCEDENTITITES._options = None
_RESPONSEGETREFERENCEDENTITITES._options = None
_REQUESTGETPARTIALPEERINFO.fields_by_name['users']._options = None
_REQUESTGETPARTIALPEERINFO.fields_by_name['groups']._options = None
_REQUESTGETPARTIALPEERINFO.fields_by_name['group_members']._options = None
_REQUESTGETPARTIALPEERINFO._options = None
_RESPONSEGETPARTIALPEERINFO.fields_by_name['users']._options = None
_RESPONSEGETPARTIALPEERINFO.fields_by_name['groups']._options = None
_RESPONSEGETPARTIALPEERINFO._options = None
_UPDATERAWUPDATE.fields_by_name['type']._options = None
_UPDATERAWUPDATE.fields_by_name['bytes']._options = None
_REQUESTSUBSCRIBETOONLINE.fields_by_name['users']._options = None
_REQUESTSUBSCRIBETOONLINE._options = None
_REQUESTSUBSCRIBEFROMONLINE.fields_by_name['users']._options = None
_REQUESTSUBSCRIBEFROMONLINE._options = None
_REQUESTSUBSCRIBETOGROUPONLINE.fields_by_name['groups']._options = None
_REQUESTSUBSCRIBETOGROUPONLINE._options = None
_REQUESTSUBSCRIBEFROMGROUPONLINE.fields_by_name['groups']._options = None
_REQUESTSUBSCRIBEFROMGROUPONLINE._options = None

_SEQUENCEANDUPDATES = _descriptor.ServiceDescriptor(
  name='SequenceAndUpdates',
  full_name='dialog.SequenceAndUpdates',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=12496,
  serialized_end=14001,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetState',
    full_name='dialog.SequenceAndUpdates.GetState',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETSTATE,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002)\"$/v1/grpc/SequenceAndUpdates/GetState:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDifference',
    full_name='dialog.SequenceAndUpdates.GetDifference',
    index=1,
    containing_service=None,
    input_type=_REQUESTGETDIFFERENCE,
    output_type=_RESPONSEGETDIFFERENCE,
    serialized_options=b'\202\323\344\223\002.\")/v1/grpc/SequenceAndUpdates/GetDifference:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDialogsDifference',
    full_name='dialog.SequenceAndUpdates.GetDialogsDifference',
    index=2,
    containing_service=None,
    input_type=_REQUESTGETDIALOGSDIFFERENCE,
    output_type=_RESPONSEGETDIALOGSDIFFERENCE,
    serialized_options=b'\202\323\344\223\0025\"0/v1/grpc/SequenceAndUpdates/GetDialogsDifference:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReferencedEntitites',
    full_name='dialog.SequenceAndUpdates.GetReferencedEntitites',
    index=3,
    containing_service=None,
    input_type=_REQUESTGETREFERENCEDENTITITES,
    output_type=_RESPONSEGETREFERENCEDENTITITES,
    serialized_options=b'\202\323\344\223\0027\"2/v1/grpc/SequenceAndUpdates/GetReferencedEntitites:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPartialPeerInfo',
    full_name='dialog.SequenceAndUpdates.GetPartialPeerInfo',
    index=4,
    containing_service=None,
    input_type=_REQUESTGETPARTIALPEERINFO,
    output_type=_RESPONSEGETPARTIALPEERINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeToOnline',
    full_name='dialog.SequenceAndUpdates.SubscribeToOnline',
    index=5,
    containing_service=None,
    input_type=_REQUESTSUBSCRIBETOONLINE,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\0022\"-/v1/grpc/SequenceAndUpdates/SubscribeToOnline:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeFromOnline',
    full_name='dialog.SequenceAndUpdates.SubscribeFromOnline',
    index=6,
    containing_service=None,
    input_type=_REQUESTSUBSCRIBEFROMONLINE,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\0024\"//v1/grpc/SequenceAndUpdates/SubscribeFromOnline:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeToGroupOnline',
    full_name='dialog.SequenceAndUpdates.SubscribeToGroupOnline',
    index=7,
    containing_service=None,
    input_type=_REQUESTSUBSCRIBETOGROUPONLINE,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\0027\"2/v1/grpc/SequenceAndUpdates/SubscribeToGroupOnline:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeFromGroupOnline',
    full_name='dialog.SequenceAndUpdates.SubscribeFromGroupOnline',
    index=8,
    containing_service=None,
    input_type=_REQUESTSUBSCRIBEFROMGROUPONLINE,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\0029\"4/v1/grpc/SequenceAndUpdates/SubscribeFromGroupOnline:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SeqUpdates',
    full_name='dialog.SequenceAndUpdates.SeqUpdates',
    index=9,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SEQUPDATEBOX,
    serialized_options=b'\202\323\344\223\002+\"&/v1/grpc/SequenceAndUpdates/SeqUpdates:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WeakUpdates',
    full_name='dialog.SequenceAndUpdates.WeakUpdates',
    index=10,
    containing_service=None,
    input_type=_WEAKUPDATECOMMAND,
    output_type=_WEAKUPDATEBOX,
    serialized_options=b'\202\323\344\223\002,\"\'/v1/grpc/SequenceAndUpdates/WeakUpdates:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SEQUENCEANDUPDATES)

DESCRIPTOR.services_by_name['SequenceAndUpdates'] = _SEQUENCEANDUPDATES

# @@protoc_insertion_point(module_scope)
